@@ -1,19 +1,9 @@
-/***************************************************************************
-                          showedittextfileagent  -  description
-                             -------------------
-    begin                : Tue Sep 13 2005
-    copyright            : (C) 2005-2016 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+showedittextfileagent - This file is part of RKWard (https://rkward.kde.org). Created: Tue Sep 13 2005
+SPDX-FileCopyrightText: 2005-2016 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "showedittextfileagent.h"
 
@@ -34,8 +24,8 @@ ShowEditTextFileAgent::ShowEditTextFileAgent (RBackendRequest *request, const QS
 
 	ShowEditTextFileAgent::request = request;
 
-	message = new KMessageWidget (0);
-	message->setText (QString ("<p><strong>%1<strong></p><p>%2</p>").arg (caption).arg (text));
+	message = new KMessageWidget(nullptr);
+	message->setText(QString("<p><strong>%1<strong></p><p>%2</p>").arg(caption, text));
 	if (request) {
 		message->setCloseButtonVisible (false);
 		QAction *done_action = new QAction (QIcon::fromTheme ("dialog-ok"), i18n ("Done"), message);
