@@ -1,19 +1,9 @@
-/***************************************************************************
-                          renvironmentobject  -  description
-                             -------------------
-    begin                : Wed Sep 27 2006
-    copyright            : (C) 2006-2019 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+renvironmentobject - This file is part of RKWard (https://rkward.kde.org). Created: Wed Sep 27 2006
+SPDX-FileCopyrightText: 2006-2019 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "renvironmentobject.h"
 
@@ -153,7 +143,7 @@ bool REnvironmentObject::updateStructure (RData *new_data) {
 	RK_ASSERT (new_data->getDataLength () >= StorageSizeBasicInfo);
 
 	if (!(type & ToplevelEnv)) {
-		if (!RObject::updateStructure (new_data)) return false;
+		if (!RContainerObject::updateStructure(new_data)) return false;
 	}
 
 	RData::RDataStorage new_data_data = new_data->structureVector ();
