@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkmodificationtracker  -  description
-                             -------------------
-    begin                : Tue Aug 31 2004
-    copyright            : (C) 2004 - 2017 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkmodificationtracker - This file is part of the RKWard project. Created: Tue Aug 31 2004
+SPDX-FileCopyrightText: 2004-2017 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKMODIFICATIONTRACKER_H
 #define RKMODIFICATIONTRACKER_H
 
