@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkpseudoobjects  -  description
-                             -------------------
-    begin                : Fri Mar 11 2011
-    copyright            : (C) 2011-2013 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkpseudoobjects - This file is part of the RKWard project. Created: Fri Mar 11 2011
+SPDX-FileCopyrightText: 2011-2013 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKPSEUDOOBJECTS_H
 #define RKPSEUDOOBJECTS_H
 
@@ -48,7 +38,7 @@ rather call it a "special" object, instead).
 */
 class RKNamespaceObject : public REnvironmentObject {
 public:
-	explicit RKNamespaceObject (REnvironmentObject* package, const QString name = QString ());
+	explicit RKNamespaceObject (REnvironmentObject* package, const QString &name = QString ());
 	~RKNamespaceObject ();
 
 	QString getFullName (int) const override;
