@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkrownames  -  description
-                             -------------------
-    begin                : Tue Mar 21 2010
-    copyright            : (C) 2010, 2013 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkrownames - This file is part of RKWard (https://rkward.kde.org). Created: Tue Mar 21 2010
+SPDX-FileCopyrightText: 2010-2013 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkrownames.h"
 
@@ -139,7 +129,7 @@ bool RKRowNames::makeUnique (QString *text, bool non_sequentials_only) {
 
 	if (!check_duplicates) return true;
 
-	bool from_index = 0;
+	int from_index = 0;
 	if (non_sequentials_only) from_index = is_sequential_up_to_row + 1;
 
 	QString dummy = *text;
