@@ -1,19 +1,9 @@
-/***************************************************************************
-                          robjectlist  -  description
-                             -------------------
-    begin                : Wed Aug 18 2004
-    copyright            : (C) 2004-2019 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+robjectlist - This file is part of RKWard (https://rkward.kde.org). Created: Wed Aug 18 2004
+SPDX-FileCopyrightText: 2004-2019 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "robjectlist.h"
 
 #define UPDATE_DELAY_INTERVAL 500
@@ -112,7 +102,7 @@ void RObjectList::updateFromR (RCommandChain *chain) {
 		return;
 	}
 
-	emit (updateStarted ());
+	emit updateStarted();
 	update_chain = RKGlobals::rInterface ()->startChain (chain);
 
 	RCommand *command = new RCommand ("list (search (), loadedNamespaces ())", RCommand::App | RCommand::Sync | RCommand::GetStructuredData, QString (), this, ROBJECTLIST_UPDATE_ENVIRONMENTS_COMMAND);
@@ -130,7 +120,7 @@ void RObjectList::updateFromR (RCommandChain *chain, const QStringList &current_
 		return;
 	}
 
-	emit (updateStarted ());
+	emit updateStarted();
 	update_chain = RKGlobals::rInterface ()->startChain (chain);
 
 	updateEnvironments (current_searchpath, false);
@@ -160,7 +150,7 @@ void RObjectList::rCommandDone (RCommand *command) {
 		update_chain = 0;
 	
 		RK_DEBUG (OBJECTS, DL_DEBUG, "object list update complete");
-		emit (updateComplete ());
+		emit updateComplete();
 	} else {
 		RK_ASSERT (false);
 	}
@@ -217,7 +207,7 @@ void RObjectList::updateEnvironments (const QStringList &_env_names, bool force_
 	RK_DO (RK_ASSERT (childmap == newchildmap), OBJECTS, DL_DEBUG);	// this is an expensive assert, hence wrapping it inside RK_DO
 }
 
-void RObjectList::updateNamespaces (const QStringList namespace_names) {
+void RObjectList::updateNamespaces (const QStringList &namespace_names) {
 	RK_TRACE (OBJECTS);
 
 	QStringList orphan_namespace_names;
