@@ -1,19 +1,9 @@
-/***************************************************************************
-                          robjectlist  -  description
-                             -------------------
-    begin                : Wed Aug 18 2004
-    copyright            : (C) 2004-2019 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+robjectlist - This file is part of the RKWard project. Created: Wed Aug 18 2004
+SPDX-FileCopyrightText: 2004-2019 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef ROBJECTLIST_H
 #define ROBJECTLIST_H
 
@@ -87,7 +77,7 @@ protected:
 	bool updateStructure (RData *new_data) override;
 	void rCommandDone (RCommand *command) override;
 	void updateEnvironments (const QStringList &env_names, bool force_globalenv_update);
-	void updateNamespaces (const QStringList namespace_names);
+	void updateNamespaces (const QStringList &namespace_names);
 private:
 	friend class RKLoadAgent;
 	friend class RKSaveAgent;
