@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkloadlibsdialog  -  description
-                             -------------------
-    begin                : Mon Sep 6 2004
-    copyright            : (C) 2004 - 2018 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkloadlibsdialog - This file is part of RKWard (https://rkward.kde.org). Created: Mon Sep 6 2004
+SPDX-FileCopyrightText: 2004-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "rkloadlibsdialog.h"
 
 #include <qwidget.h>
@@ -51,8 +41,6 @@
 #include <stdlib.h>
 
 
-#define GET_CURRENT_LIBLOCS_COMMAND 1
-
 RKLoadLibsDialog::RKLoadLibsDialog (QWidget *parent, RCommandChain *chain, bool modal) : KPageDialog (parent) {
 	RK_TRACE (DIALOGS);
 	RKLoadLibsDialog::chain = chain;
@@ -77,14 +65,19 @@ RKLoadLibsDialog::RKLoadLibsDialog (QWidget *parent, RCommandChain *chain, bool
 	num_child_widgets = 4;
 	was_accepted = false;
 
-	RKGlobals::rInterface ()->issueCommand (".libPaths ()", RCommand::App | RCommand::GetStringVector, QString (), this, GET_CURRENT_LIBLOCS_COMMAND, chain);
+	RCommand *command = new RCommand(".libPaths()", RCommand::App | RCommand::GetStringVector);
+	connect(command->notifier(), &RCommandNotifier::commandFinished, this, [this](RCommand *command) {
+		RK_ASSERT (command->getDataType() == RData::StringVector);
+		RK_ASSERT (command->getDataLength() > 0);
+		// NOTE: The problem is that e.g. R_LIBS_USER is not in .libPaths() if it does not exist, yet. But it should be available as an option, of course
+		library_locations = command->stringVector();
+		emit libraryLocationsChanged(library_locations);
+	});
+	RKGlobals::rInterface()->issueCommand(command, chain);
 }
 
 RKLoadLibsDialog::~RKLoadLibsDialog () {
 	RK_TRACE (DIALOGS);
-
-	if (was_accepted) KPageDialog::accept ();
-	else KPageDialog::reject ();
 }
 
 KPageWidgetItem* RKLoadLibsDialog::addChild (QWidget *child_page, const QString &caption) {
@@ -106,15 +99,14 @@ void RKLoadLibsDialog::slotPageChanged () {
 }
 
 //static
-void RKLoadLibsDialog::showInstallPackagesModal (QWidget *parent, RCommandChain *chain, const QString &package_name) {
-	RK_TRACE (DIALOGS);
+void RKLoadLibsDialog::showInstallPackagesModal(QWidget *parent, RCommandChain *chain, const QStringList &package_names) {
+	RK_TRACE(DIALOGS);
 
-	RKLoadLibsDialog *dialog = new RKLoadLibsDialog (parent, chain, true);
-	dialog->auto_install_package = package_name;
-	QTimer::singleShot (0, dialog, SLOT (automatedInstall()));		// to get past the dialog->exec, below
-	dialog->setCurrentPage (dialog->install_packages_pageitem);
-	dialog->exec ();
-	RK_TRACE (DIALOGS);
+	RKLoadLibsDialog *dialog = new RKLoadLibsDialog(parent, chain, true);
+	QTimer::singleShot(0, dialog, [dialog, package_names]() { dialog->automatedInstall(package_names); });   // to get past the dialog->exec, below
+	dialog->setCurrentPage(dialog->install_packages_pageitem);
+	dialog->exec();
+	RK_TRACE(DIALOGS);
 }
 
 // static
@@ -126,11 +118,11 @@ void RKLoadLibsDialog::showPluginmapConfig (QWidget* parent, RCommandChain* chai
 	dialog->show ();
 }
 
-void RKLoadLibsDialog::automatedInstall () {
+void RKLoadLibsDialog::automatedInstall(const QStringList &packages) {
 	RK_TRACE (DIALOGS);
 
-	install_packages_widget->initialize ();
-	install_packages_widget->trySelectPackage (auto_install_package);
+	install_packages_widget->initialize();
+	install_packages_widget->trySelectPackages(packages);
 }
 
 void RKLoadLibsDialog::tryDestruct () {
@@ -159,27 +151,14 @@ void RKLoadLibsDialog::accept () {
 	was_accepted = true;
 	hide ();
 	// will self-destruct once all children are done
-	emit (accepted());
+	emit accepted();
 }
 
 void RKLoadLibsDialog::reject () {
 	was_accepted = false;
 	hide ();
 	// will self-destruct once all children are done
-	emit (rejected());
-}
-
-void RKLoadLibsDialog::rCommandDone (RCommand *command) {
-	RK_TRACE (DIALOGS);
-	if (command->getFlags () == GET_CURRENT_LIBLOCS_COMMAND) {
-		RK_ASSERT (command->getDataType () == RData::StringVector);
-		RK_ASSERT (command->getDataLength () > 0);
-		// NOTE: The problem is that e.g. R_LIBS_USER is not in .libPaths() if it does not exist, yet. But it should be available as an option, of course
-		library_locations = command->stringVector ();
-		emit (libraryLocationsChanged (library_locations));
-	} else {
-		RK_ASSERT (false);
-	}
+	emit rejected();
 }
 
 void RKLoadLibsDialog::addLibraryLocation (const QString& new_loc) {
@@ -189,7 +168,7 @@ void RKLoadLibsDialog::addLibraryLocation (const QString& new_loc) {
 
 	if (QDir ().mkpath (new_loc)) RKSettingsModuleRPackages::addLibraryLocation (new_loc, chain);
 	library_locations.prepend (new_loc);
-	emit (libraryLocationsChanged (library_locations));
+	emit libraryLocationsChanged(library_locations);
 }
 
 bool RKLoadLibsDialog::removePackages (QStringList packages, QStringList from_liblocs) {
@@ -379,39 +358,35 @@ void RKLoadLibsDialog::runInstallationCommand (const QString& command, bool as_r
 	file.remove ();
 	delete installation_process;
 	installation_process = 0;
-	emit (installedPackagesChanged ());
+	emit installedPackagesChanged();
 }
 
 void RKLoadLibsDialog::installationProcessOutput () {
 	RK_TRACE (DIALOGS);
 	RK_ASSERT (installation_process);
 
-	emit (installationOutput (QString::fromLocal8Bit (installation_process->readAllStandardOutput())));
+	emit installationOutput(QString::fromLocal8Bit(installation_process->readAllStandardOutput()));
 }
 
 void RKLoadLibsDialog::installationProcessError () {
 	RK_TRACE (DIALOGS);
 	RK_ASSERT (installation_process);
 
-	emit (installationError (QString::fromLocal8Bit (installation_process->readAllStandardError ())));
+	emit installationError(QString::fromLocal8Bit(installation_process->readAllStandardError()));
 }
 
 void RKLoadLibsDialog::processExited (int exitCode, QProcess::ExitStatus exitStatus) {
 	RK_TRACE (DIALOGS);
 
 	if (exitCode || (exitStatus != QProcess::NormalExit)) {
-		installationError ('\n' + i18n ("Installation process died with exit code %1", exitCode));
+		emit installationError('\n' + i18n ("Installation process died with exit code %1", exitCode));
 	}
 
-	emit (installationComplete ());
+	emit installationComplete();
 }
 
 ////////////////////// LoadUnloadWidget ////////////////////////////
 
-#define GET_INSTALLED_PACKAGES 1
-#define GET_LOADED_PACKAGES 2
-#define LOAD_PACKAGE_COMMAND 3
-
 LoadUnloadWidget::LoadUnloadWidget (RKLoadLibsDialog *dialog) : QWidget (0) {
 	RK_TRACE (DIALOGS);
 	LoadUnloadWidget::parent = dialog;
@@ -472,10 +447,15 @@ void LoadUnloadWidget::activated () {
 	installed_view->setFocus ();
 }
 
-void LoadUnloadWidget::rCommandDone (RCommand *command) {
+void LoadUnloadWidget::updateInstalledPackages () {
 	RK_TRACE (DIALOGS);
-	if (command->failed ()) return;
-	if (command->getFlags () == GET_INSTALLED_PACKAGES) {
+
+	installed_view->clear ();
+	loaded_view->clear ();
+
+	auto command = new RCommand(".rk.get.installed.packages()", RCommand::App | RCommand::Sync | RCommand::GetStructuredData);
+	connect(command->notifier(), &RCommandNotifier::commandFinished, this, [this](RCommand *command) {
+		if (command->failed()) return;
 		RK_ASSERT (command->getDataLength () == 5);
 
 		RData::RDataStorage data = command->structureVector ();
@@ -498,7 +478,12 @@ void LoadUnloadWidget::rCommandDone (RCommand *command) {
 		installed_view->resizeColumnToContents (0);
 		installed_view->setSortingEnabled (true);
 		installed_view->sortItems (0, Qt::AscendingOrder);
-	} else if (command->getFlags () == GET_LOADED_PACKAGES) {
+	});
+	RKGlobals::rInterface ()->issueCommand(command, parent->chain);
+
+	command = new RCommand(".packages()", RCommand::App | RCommand::Sync | RCommand::GetStringVector);
+	connect(command->notifier(), &RCommandNotifier::commandFinished, this, [this](RCommand *command) {
+		if (command->failed()) return;
 		RK_ASSERT (command->getDataType () == RData::StringVector);
 		QStringList data = command->stringVector ();
 		for (int i=0; i < data.size (); ++i) {
@@ -512,21 +497,8 @@ void LoadUnloadWidget::rCommandDone (RCommand *command) {
 		loaded_view->setSortingEnabled (true);
 		loaded_view->sortItems (0, Qt::AscendingOrder);
 		updateCurrentList ();
-	} else if (command->getFlags () == LOAD_PACKAGE_COMMAND) {
-		emit (loadUnloadDone ());
-	} else {
-		RK_ASSERT (false);
-	}
-}
-
-void LoadUnloadWidget::updateInstalledPackages () {
-	RK_TRACE (DIALOGS);
-
-	installed_view->clear ();
-	loaded_view->clear ();
-
-	RKGlobals::rInterface ()->issueCommand (".rk.get.installed.packages ()", RCommand::App | RCommand::Sync | RCommand::GetStructuredData, QString (), this, GET_INSTALLED_PACKAGES, parent->chain);
-	RKGlobals::rInterface ()->issueCommand (".packages ()", RCommand::App | RCommand::Sync | RCommand::GetStringVector, QString (), this, GET_LOADED_PACKAGES, parent->chain);
+	});
+	RKGlobals::rInterface()->issueCommand(command, parent->chain);
 }
 
 void LoadUnloadWidget::loadButtonClicked () {
@@ -618,10 +590,13 @@ void LoadUnloadWidget::doLoadUnload () {
 	}
 
 	// find out, when we're done
-	RCommand *command = new RCommand (QString (), RCommand::EmptyCommand, QString (), this, LOAD_PACKAGE_COMMAND);
-	RKGlobals::rInterface ()->issueCommand (command, parent->chain);
+	RCommand *command = new RCommand(QString(), RCommand::EmptyCommand);
+	connect(command->notifier(), &RCommandNotifier::commandFinished, this, [this](RCommand *) {
+		emit loadUnloadDone();
+	});
+	RKGlobals::rInterface()->issueCommand(command, parent->chain);
 
-	control->doNonModal (true);
+	control->doNonModal(true);
 }
 
 void LoadUnloadWidget::apply () {
@@ -783,14 +758,20 @@ void InstallPackagesWidget::filterChanged () {
 	// NOTE: filter string already set by RKDynamicSearchLine
 }
 
-void InstallPackagesWidget::trySelectPackage (const QString &package_name) {
+void InstallPackagesWidget::trySelectPackages (const QStringList &package_names) {
 	RK_TRACE (DIALOGS);
 
-	QModelIndex index = packages_status->markPackageForInstallation (package_name);
-	if (!index.isValid ()) {
-		KMessageBox::sorry (0, i18n ("The package requested by the backend (\"%1\") was not found in the package repositories. Maybe the package name was mis-spelled. Or maybe you need to add additional repositories via the \"Configure Repositories\" button.", package_name), i18n ("Package not available"));
-	} else {
-		packages_view->scrollTo (model->mapFromSource (index));
+	QStringList failed_names;
+	for (int i = 0; i < package_names.size(); ++i) {
+		QModelIndex index = packages_status->markPackageForInstallation(package_names[i]);
+		if (!index.isValid()) {
+			failed_names.append(package_names[i]);
+		} else {
+			packages_view->scrollTo(model->mapFromSource(index));
+		}
+	}
+	if (!failed_names.isEmpty()) {
+		KMessageBox::sorry (0, i18n ("The following package(s) requested by the backend have not been found in the package repositories: \"%1\". Maybe the package name was mis-spelled. Or maybe you need to add additional repositories via the \"Configure Repositories\" button.", failed_names.join("\", \"")), i18n ("Package not available"));
 	}
 }
 
@@ -1185,8 +1166,8 @@ bool RKRPackageInstallationStatus::setData (const QModelIndex &index, const QVar
 	if (irow >= 0) installed_status[irow] = stat;
 	if (arow >= 0) available_status[arow] = stat;
 
-	dataChanged (index, index);
-	if (bindex.isValid ()) dataChanged (bindex, bindex);
+	emit dataChanged(index, index);
+	if (bindex.isValid ()) emit dataChanged(bindex, bindex);
 
 	return true;
 }
