@@ -1,27 +1,15 @@
-/***************************************************************************
-                          rkreadlinedialog  -  description
-                             -------------------
-    begin                : Fri Sep 15 2006
-    copyright            : (C) 2006, 2007, 2008, 2009 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkreadlinedialog - This file is part of RKWard (https://rkward.kde.org). Created: Fri Sep 15 2006
+SPDX-FileCopyrightText: 2006-2009 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkreadlinedialog.h"
 
 #include <qlineedit.h>
 #include <QTextEdit>
 #include <qlabel.h>
-#include <qapplication.h>
-#include <qdesktopwidget.h>
 #include <QScrollBar>
 #include <QTimer>
 #include <QVBoxLayout>
@@ -47,7 +35,7 @@ RKReadLineDialog::RKReadLineDialog (QWidget *parent, const QString &caption, con
 
 	layout->addWidget (new QLabel (caption, this));
 
-	int screen_width = qApp->desktop ()->availableGeometry (this).width ();
+	int screen_width = RKCommonFunctions::availableGeometry(this).width();
 
 	QString context = command->fullOutput ();
 	if (!context.isEmpty ()) {
