@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rksetupwizard  -  description
-                             -------------------
-    begin                : Fri May 25 20200
-    copyright            : (C) 2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rksetupwizard - This file is part of RKWard (https://rkward.kde.org). Created: Fri May 25 20200
+SPDX-FileCopyrightText: 2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rksetupwizard.h"
 
@@ -25,10 +15,12 @@
 #include <QGridLayout>
 #include <QIcon>
 #include <QPushButton>
+#include <QTimer>
+#include <QFileInfo>
+#include <QStandardPaths>
 
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <QStandardPaths>
 
 #include "../settings/rksettingsmoduleplugins.h"
 #include "../settings/rksettingsmodulegeneral.h"
@@ -72,11 +64,11 @@ void RKSetupWizardItem::createWidget(QGridLayout *layout, int row) {
 	if (!(longlabel.isEmpty() && options.isEmpty())) {
 		QString details = longlabel;
 		for (int i = 0; i < options.size(); ++i) {
-			details += QString("<p><b>%1</b>: %2</p>").arg(options[i].shortlabel).arg(options[i].longlabel);
+			details += QString("<p><b>%1</b>: %2</p>").arg(options[i].shortlabel, options[i].longlabel);
 		}
 		auto info = new QPushButton();
 		info->setIcon(RKStandardIcons::getIcon(RKStandardIcons::WindowHelp));
-		QObject::connect(info, &QPushButton::clicked, [details, layout]() { KMessageBox::information(layout->parentWidget(), details, QString(), QString(), KMessageBox::Notify | KMessageBox::AllowLink); });
+		QObject::connect(info, &QPushButton::clicked, layout, [details, layout]() { KMessageBox::information(layout->parentWidget(), details, QString(), QString(), KMessageBox::Notify | KMessageBox::AllowLink); });
 		layout->addWidget(info, row, 3);
 	}
 }
@@ -130,17 +122,17 @@ RKSetupWizard::RKSetupWizard(QWidget* parent, InvokationReason reason, const QLi
 	auto l = new QVBoxLayout(firstpage);
 	QString intro = i18n("<p>This dialog will guide you through a quick check of the basic setup of the required (or recommended) components.</p>");
 	if (reason == NewVersionRKWard) {
-		intro += i18n("<p>The setup assistant has been invoked, automatically, because a new version of RKWard has been detected.</p");
+		intro += i18n("<p>The setup assistant has been invoked, automatically, because a new version of RKWard has been detected.</p>");
 	} else if (reason == NewVersionR) {
 		// TODO: invoke this!
-		intro += i18n("<p>The setup assistant has been invoked, automatically, because a new version of R has been detected.</p");
+		intro += i18n("<p>The setup assistant has been invoked, automatically, because a new version of R has been detected.</p>");
 	} else if (reason == ProblemsDetected) {
-		intro += i18n("<p>The setup assistant has been invoked, automatically, because a problem has been detected in your setup.</p");
+		intro += i18n("<p>The setup assistant has been invoked, automatically, because a problem has been detected in your setup.</p>");
 	}
 	l->addWidget(RKCommonFunctions::wordWrappedLabel(intro));
-	auto waiting_to_start_label = RKCommonFunctions::wordWrappedLabel(i18n("<b>Waiting for R backend...</b>") + "<p>&nbsp;</p><p>&nbsp;</p>");
+	waiting_to_start_label = RKCommonFunctions::wordWrappedLabel(i18n("<b>Waiting for R backend...</b>") + "<p>&nbsp;</p><p>&nbsp;</p>");
 	l->addWidget(waiting_to_start_label);
-	auto firstpageref = addPage (firstpage, i18n("RKWard Setup Assistant"));
+	firstpageref = addPage (firstpage, i18n("RKWard Setup Assistant"));
 	setValid(firstpageref, false);
 
 	// Basic installation page
@@ -181,6 +173,19 @@ RKSetupWizard::RKSetupWizard(QWidget* parent, InvokationReason reason, const QLi
 	}
 	appendItem(kateplugins);
 
+	// TODO: Remove, eventually
+	auto legacy_output = new RKSetupWizardItem(i18n("Pre 0.7.3 output file"));
+	QString legacy_output_path = RKSettingsModuleGeneral::filesPath() + "rk_out.html";
+	if (QFileInfo::exists(legacy_output_path)) {
+		legacy_output->setStatus(RKSetupWizardItem::Warning, i18n("Exists"));
+		legacy_output->setLongLabel(QString("<p>An output file from before RKWard version 0.7.3 was found (%1). You will probably want to convert this to the new format. Alternatively, if it is no longer needed, you can delete it, manually.</p>").arg(legacy_output_path));
+		legacy_output->addOption(i18n("Import"), i18n("Import to the session, so you can save in the new output format."), [](RKSetupWizard* wizard) { wizard->r_commands_to_run.append("rk.import.legacy.output()\n"); });
+		legacy_output->addOption(i18n("No action"), i18n("Ignore (and keep) the file. You can import it manually, at any time, using rk.import.legacy.output()"), [](RKSetupWizard*) {});
+	} else {
+		legacy_output->setStatus(RKSetupWizardItem::Good, i18n("Found."));
+	}
+	appendItem(legacy_output);
+
 	for (int i = 0; i < settings_items.size(); ++i) {
 		appendItem(settings_items[i]);
 	}
@@ -188,16 +193,23 @@ RKSetupWizard::RKSetupWizard(QWidget* parent, InvokationReason reason, const QLi
 	current_layout->setRowStretch(++current_row, 1);
 	addPage(current_page, i18n("Basic installation"));
 
-	// Wait for R Interface, then start dialog
-	setWindowModality(Qt::ApplicationModal);
-	show();
-	while (!RKGlobals::rInterface()->backendIsIdle()) {
+	// Next we'll want to wait for the R backend to start up. Previous solution was to set Qt::ApplicationModal, and wait, calling processEvents().
+	// This does not seem to work well on mac, however, so instead we return, here, so exec will be called from outside, then fire a timer to finish constuction.
+	QTimer::singleShot(10, this, &RKSetupWizard::setupWizardPhase2);
+}
+
+void RKSetupWizard::setupWizardPhase2() {
+	// Wait for R Interface, then enable dialog
+	if (!RKGlobals::rInterface()->backendIsIdle()) {
 		if (RKGlobals::rInterface()->backendIsDead()) {
 			waiting_to_start_label->setText(i18n("<b>R backend has crashed. Click \"Cancel\" to exit setup assistant.</b>"));
 		} else {
-			QApplication::processEvents(QEventLoop::AllEvents, 1000);
+			QTimer::singleShot(100, this, &RKSetupWizard::setupWizardPhase2);
 		}
+		return;
 	}
+	RK_TRACE(APP);
+
 	waiting_to_start_label->setText(i18n("<b>R backend has started. Click \"Next\" to continue.</b>"));
 	setValid(firstpageref, true);
 
@@ -319,6 +331,9 @@ void RKSetupWizard::fullInteractiveCheck(InvokationReason reason, const QList<RK
 			}
 		}
 #endif
+		for(int i = 0; i < wizard->r_commands_to_run.size(); ++i) {
+			RKGlobals::rInterface()->issueCommand(wizard->r_commands_to_run[i], RCommand::App);
+		}
 	}
 
 	delete wizard;
