@@ -1,19 +1,9 @@
-/***************************************************************************
-                          startupdialog  -  description
-                             -------------------
-    begin                : Thu Aug 26 2004
-    copyright            : (C) 2004, 2011 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+startupdialog - This file is part of the RKWard project. Created: Thu Aug 26 2004
+SPDX-FileCopyrightText: 2004-2011 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef STARTUPDIALOG_H
 #define STARTUPDIALOG_H
 
