@@ -1,19 +1,9 @@
-/***************************************************************************
-                          editformatdialog  -  description
-                             -------------------
-    begin                : Thu Sep 30 2004
-    copyright            : (C) 2004 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+editformatdialog - This file is part of RKWard (https://rkward.kde.org). Created: Thu Sep 30 2004
+SPDX-FileCopyrightText: 2004 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "editformatdialog.h"
 
 #include <QButtonGroup>
@@ -142,9 +132,9 @@ void EditFormatDialogProxy::dialogDone (int result) {
 
 	if (result == QDialog::Accepted) {
 		options = dialog->options;
-		emit (done (this, RKItemDelegate::EditorExit));
+		emit done(this, RKItemDelegate::EditorExit);
 	} else {
-		emit (done (this, RKItemDelegate::EditorReject));
+		emit done(this, RKItemDelegate::EditorReject);
 	}
 	dialog->deleteLater ();
 	dialog = 0;
