@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkobjectlistview  -  description
-                             -------------------
-    begin                : Wed Sep 1 2004
-    copyright            : (C) 2004-2018 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkobjectlistview - This file is part of RKWard (https://rkward.kde.org). Created: Wed Sep 1 2004
+SPDX-FileCopyrightText: 2004-2018 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "rkobjectlistview.h"
 
 #include <KLocalizedString>
@@ -140,7 +130,7 @@ RObject* RKObjectListView::objectAtIndex (const QModelIndex& index) const {
 void RKObjectListView::selectionChanged (const QItemSelection&, const QItemSelection&) {
 	RK_TRACE (APP);
 
-	emit (selectionChanged ());
+	emit selectionChanged();
 }
 
 RObject::ObjectList RKObjectListView::selectedObjects () const {
@@ -162,7 +152,7 @@ void RKObjectListView::contextMenuEvent (QContextMenuEvent* event) {
 
 	menu_object = objectAtIndex (indexAt (event->pos ()));
 	bool suppress = false;
-	emit (aboutToShowContextMenu (menu_object, &suppress));
+	emit aboutToShowContextMenu(menu_object, &suppress);
 
 	if (!suppress) menu->popup (event->globalPos ());
 }
@@ -515,5 +505,5 @@ void RKObjectListViewSettings::updateSelfNow () {
 
 	invalidateFilter ();
 
-	emit (settingsChanged ());
+	emit settingsChanged();
 }
