@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkprogresscontol  -  description
-                             -------------------
-    begin                : Sun Sep 10 2006
-    copyright            : (C) 2006, 2007, 2008, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkprogresscontol - This file is part of RKWard (https://rkward.kde.org). Created: Sun Sep 10 2006
+SPDX-FileCopyrightText: 2006-2011 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkprogresscontrol.h"
 
@@ -26,6 +16,7 @@
 #include <QDialogButtonBox>
 
 #include <KLocalizedString>
+#include <KColorScheme>
 
 #include "../rkglobals.h"
 #include "../rbackend/rkrinterface.h"
@@ -62,6 +53,7 @@ private:
 	ROutput::ROutputType last_output_type;
 	bool prevent_close;
 	bool is_done;
+	KColorScheme color_scheme;
 };
 
 
@@ -169,11 +161,11 @@ void RKProgressControl::dialogDestroyed () {
 	if ((!is_done) && (mode & AllowCancel)) {
 		is_done = true;
 		if (mode & AutoCancelCommands) {
-			for (RCommandList::const_iterator it = outstanding_commands.begin (); it != outstanding_commands.end (); ++it) {
+			for (RCommandList::const_iterator it = outstanding_commands.cbegin (); it != outstanding_commands.cend (); ++it) {
 				RKGlobals::rInterface ()->cancelCommand (*it);
 			}
 		}
-		emit (cancelled ());
+		emit cancelled();
 	}
 }
 
@@ -236,7 +228,7 @@ QString RKProgressControl::fullCommandOutput() {
 
 #include <kstandardguiitem.h>
 
-RKProgressControlDialog::RKProgressControlDialog (const QString &text, const QString &caption, int mode_flags, bool modal) : QDialog (0) {
+RKProgressControlDialog::RKProgressControlDialog(const QString &text, const QString &caption, int mode_flags, bool modal) : QDialog(nullptr), color_scheme(QPalette::Normal) {
 	RK_TRACE (MISC);
 
 	setAttribute (Qt::WA_DeleteOnClose, true);
@@ -323,9 +315,9 @@ void RKProgressControlDialog::addOutput (const ROutput *output) {
 		output_text->insertPlainText ("\n");
 
 		if (output->type == ROutput::Output) {
-			output_text->setTextColor (Qt::black);
+			output_text->setTextColor(color_scheme.foreground(KColorScheme::NormalText).color());
 		} else {
-			output_text->setTextColor (Qt::red);
+			output_text->setTextColor(color_scheme.foreground(KColorScheme::NegativeText).color());
 			if (!detailsbox->isVisible ()) toggleDetails ();
 			error_indicator->show ();
 		}
