@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkprogresscontol  -  description
-                             -------------------
-    begin                : Sun Sep 10 2006
-    copyright            : (C) 2006, 2007, 2009, 2011, 2012 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkprogresscontol - This file is part of the RKWard project. Created: Sun Sep 10 2006
+SPDX-FileCopyrightText: 2006-2012 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKPROGRESSCONTROL_H
 #define RKPROGRESSCONTROL_H
 
