@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkspecialactions  -  description
-                             -------------------
-    begin                : Mon Mar 15 2010
-    copyright            : (C) 2010 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkspecialactions - This file is part of RKWard (https://rkward.kde.org). Created: Mon Mar 15 2010
+SPDX-FileCopyrightText: 2010-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkspecialactions.h"
 
@@ -21,26 +11,28 @@
 
 #include "../debug.h"
 
-RKPasteSpecialAction::RKPasteSpecialAction (QObject* parent) : KPasteTextAction (parent) {
-	RK_TRACE (MISC);
+RKPasteSpecialAction::RKPasteSpecialAction(QObject* parent) : QAction(parent) {
+	RK_TRACE(MISC);
 
-	setText (i18n ("Paste special..."));
-	connect (this, &QAction::triggered, this, &RKPasteSpecialAction::doSpecialPaste);
+	setText(i18n("Paste special..."));
+	connect(this, &QAction::triggered, this, &RKPasteSpecialAction::doSpecialPaste);
 }
 
-RKPasteSpecialAction::~RKPasteSpecialAction () {
-	RK_TRACE (MISC);
+RKPasteSpecialAction::~RKPasteSpecialAction() {
+	RK_TRACE(MISC);
 }
 
-void RKPasteSpecialAction::doSpecialPaste () {
-	RK_TRACE (MISC);
+void RKPasteSpecialAction::doSpecialPaste() {
+	RK_TRACE(MISC);
 
-	RKPasteSpecialDialog* dialog = new RKPasteSpecialDialog (associatedWidgets ().first ());
-	int res = dialog->exec ();
+	QWidget *pwin = nullptr;
+	if (!associatedWidgets().isEmpty()) pwin = associatedWidgets().at(0);
+	RKPasteSpecialDialog* dialog = new RKPasteSpecialDialog(pwin);
+	int res = dialog->exec();
 	if (res == QDialog::Accepted) {
-		emit (pasteText (dialog->resultingText()));
+		emit pasteText(dialog->resultingText());
 	}
-	dialog->deleteLater ();
+	dialog->deleteLater();
 }
 
 #include <QCheckBox>
