@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkinput  -  description
-                             -------------------
-    begin                : Sat Mar 10 2005
-    copyright            : (C) 2005, 2006, 2007, 2012, 2014 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkinput - This file is part of RKWard (https://rkward.kde.org). Created: Sat Mar 10 2005
+SPDX-FileCopyrightText: 2005-2014 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkinput.h"
 
@@ -96,17 +86,15 @@ void RKInput::updateColor () {
 	if (!widget) widget = textedit;
 	RK_ASSERT (widget);
 
-	QPalette palette = widget->palette ();
 	if (isEnabled ()) {
 		if (isSatisfied ()) {
-			palette.setColor (widget->backgroundRole (), QColor (255, 255, 255));
+			widget->setStyleSheet("");
 		} else {
-			palette.setColor (widget->backgroundRole (), QColor (255, 0, 0));
+			widget->setStyleSheet("background: red; color: black");
 		}
 	} else {
-		palette.setColor (widget->backgroundRole (), QColor (200, 200, 200));
+		widget->setStyleSheet("background: rgb(200, 200, 200); color: black");
 	}
-	widget->setPalette (palette);
 }
 
 void RKInput::requirednessChanged (RKComponentPropertyBase *) {
