@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkpluginsaveobject  -  description
-                             -------------------
-    begin                : Tue Jan 30 2007
-    copyright            : (C) 2007, 2010, 2012, 2014 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkpluginsaveobject - This file is part of RKWard (https://rkward.kde.org). Created: Tue Jan 30 2007
+SPDX-FileCopyrightText: 2007-2014 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkpluginsaveobject.h"
 
@@ -82,8 +72,8 @@ RKPluginSaveObject::~RKPluginSaveObject () {
 void RKPluginSaveObject::update () {
 	RK_TRACE (PLUGIN);
 
-	if (isSatisfied ()) selector->setBackgroundColor (QColor (255, 255, 255));
-	else selector->setBackgroundColor (QColor (255, 0, 0));
+	if (isSatisfied ()) selector->setStyleSheet(QString(""));
+	else selector->setStyleSheet(QString("background: red; color: black"));
 	changed ();
 }
 
