@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkstandardcomponentgui  -  description
-                             -------------------
-    begin                : Sun Mar 19 2006
-    copyright            : (C) 2006, 2007, 2009, 2012 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkstandardcomponentgui - This file is part of RKWard (https://rkward.kde.org). Created: Sun Mar 19 2006
+SPDX-FileCopyrightText: 2006-2012 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkstandardcomponentgui.h"
 
@@ -28,10 +18,8 @@
 #include <QSplitter>
 #include <QHBoxLayout>
 #include <QToolButton>
-#include <QDesktopWidget>
 #include <QAction>
 #include <QUrl>
-#include <QApplication>
 
 #include "rkcomponentmap.h"
 #include "../misc/rkcommonfunctions.h"
@@ -86,7 +74,7 @@ public:
 		setSizes (sizes);
 
 		if (QSplitter::window ()->isVisible ()) {
-			QRect boundary = QApplication::desktop ()->availableGeometry (this);
+			QRect boundary = RKCommonFunctions::availableGeometry(this);
 			int new_width = window->width ();
 			int new_height = window->height ();
 			int new_x = window->x ();
@@ -110,10 +98,10 @@ public:
 		}
 	};
 
-	void saveSize () {
-		if (extension->isVisible ()) {
-			if (orientation () == Qt::Horizontal) RKSettingsModulePlugins::setDefaultSidePreviewWidth (sizes ()[1]);
-			else RKSettingsModulePlugins::setDefaultCodeHeight (sizes ()[1]);
+	void saveSize() {
+		if (extension->isVisible()) {
+			if (orientation() == Qt::Horizontal) RKSettingsModulePlugins::setDefaultSidePreviewWidth(sizes().at(1));
+			else RKSettingsModulePlugins::setDefaultCodeHeight(sizes().at(1));
 		}
 	}
 
@@ -157,7 +145,7 @@ RKStandardComponentGUI::RKStandardComponentGUI (RKStandardComponent *component,
 		code_display = new RKCommandEditorWindow (0, QUrl (), QString (), RKCommandEditorFlags::DefaultToRHighlighting);
 		code_display->setReadOnly (true);
 		code_display_visibility.setBoolValue (!enslaved && RKSettingsModulePlugins::showCodeByDefault ());
-		code_display->setParent (area);  // hm, mysterious breakage when adding via constructor. Whatever...
+		area->setWindow(code_display);
 
 		KActionCollection *action_collection = new KActionCollection (this);
 		action_collection->addAction (KStandardAction::Copy, this, SLOT (copyCode()));
