@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rcommandstack  -  description
-                             -------------------
-    begin                : Mon Sep 6 2004
-    copyright            : (C) 2004-2013 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rcommandstack - This file is part of RKWard (https://rkward.kde.org). Created: Mon Sep 6 2004
+SPDX-FileCopyrightText: 2004-2013 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "rcommandstack.h"
 
 #include <KLocalizedString>
@@ -382,6 +372,6 @@ void RCommandStackModel::itemChange (RCommandChain* item) {
 	RK_TRACE (RBACKEND);
 
 	QModelIndex item_index = indexFor (item);
-	emit (dataChanged (item_index, item_index));
+	emit dataChanged(item_index, item_index);
 }
 
