@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkfrontendtransmitter  -  description
-                             -------------------
-    begin                : Thu Nov 04 2010
-    copyright            : (C) 2010-2019 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkfrontendtransmitter - This file is part of RKWard (https://rkward.kde.org). Created: Thu Nov 04 2010
+SPDX-FileCopyrightText: 2010-2019 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkfrontendtransmitter.h"
 
@@ -32,7 +22,7 @@
 #include <QLocalSocket>
 #include <QDir>
 #include <QStandardPaths>
-#include <QTime>
+#include <QElapsedTimer>
 
 #include "../version.h"
 #include "../debug.h"
@@ -111,8 +101,12 @@ void RKFrontendTransmitter::run () {
 	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/../../../rbackend");
 	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/../Frameworks/libexec");  // For running from .dmg created by craft --package rkward
 #endif
-	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (RKWARD_BACKEND_PATH);
-	if (backend_executable.isEmpty ()) handleTransmissionError (i18n ("The backend executable could not be found. This is likely to be a problem with your installation."));
+	if (backend_executable.isEmpty()) backend_executable = findBackendAtPath(RKWARD_BACKEND_PATH);
+	if (backend_executable.isEmpty()) {
+		handleTransmissionError(i18n("The backend executable could not be found. This is likely to be a problem with your installation."));
+		exec();   // To actually show the transmission error
+		return;
+	}
 	QString debugger = RKGlobals::startup_options["backend-debugger"].toString ();
 	args.prepend (RKCommonFunctions::windowsShellScriptSafeCommand (backend_executable));
 	if (!debugger.isEmpty ()) {
@@ -135,15 +129,15 @@ void RKFrontendTransmitter::run () {
 	}
 	backend->start (qgetenv ("R_BINARY"), args, QIODevice::ReadOnly);
 
-	if (!backend->waitForStarted ()) {
-		handleTransmissionError (i18n ("The backend executable could not be started. Error message was: %1", backend->errorString ()));
+	if (!backend->waitForStarted()) {
+		handleTransmissionError(i18n("The backend executable could not be started. Error message was: %1", backend->errorString()));
+	} else {
+		waitForCanReadLine(backend, 3000);
+		token = QString::fromLocal8Bit(backend->readLine()).trimmed();
+		backend->closeReadChannel(QProcess::StandardError);
+		backend->closeReadChannel(QProcess::StandardOutput);
 	}
 
-	waitForCanReadLine (backend, 3000);
-	token = QString::fromLocal8Bit (backend->readLine ()).trimmed ();
-	backend->closeReadChannel (QProcess::StandardError);
-	backend->closeReadChannel (QProcess::StandardOutput);
-
 	exec ();
 
 	// It's ok to only give backend a short time to finish. We only get here, after QuitCommand has been handled by the backend
@@ -160,9 +154,9 @@ void RKFrontendTransmitter::waitForCanReadLine (QIODevice* con, int msecs) {
 
 	// NOTE: On Qt5+Windows, readyReady may actually come in char by char, so calling waitForReadyRead() does not guarantee we will
 	//       see the full line, at all. But also, of course, we want to put some cap on trying. Using a time threshold for this.
-	QTime time;
-	time.start ();
-	while ((!con->canReadLine ()) && (time.elapsed () < msecs)) con->waitForReadyRead (500);
+	QElapsedTimer time;
+	time.start();
+	while ((!con->canReadLine()) && (time.elapsed() < msecs)) con->waitForReadyRead(500);
 }
 
 void RKFrontendTransmitter::connectAndEnterLoop () {
@@ -213,8 +207,8 @@ void RKFrontendTransmitter::backendExit (int exitcode) {
 	RK_TRACE (RBACKEND);
 
 	if (!exitcode && token.isEmpty ()) handleTransmissionError (i18n ("The backend process could not be started. Please check your installation."));
-	else if (token.isEmpty ()) handleTransmissionError (i18n ("The backend process failed to start with exit code %1.", exitcode));
-	else handleTransmissionError (i18n ("Backend process has exited with code %1.", exitcode));
+	else if (token.isEmpty ()) handleTransmissionError (i18n ("The backend process failed to start with exit code %1, message: '%2'.", exitcode, QString::fromLocal8Bit(backend->readAllStandardError())));
+	else handleTransmissionError (i18n ("Backend process has exited with code %1, message: '%2'.", exitcode, QString::fromLocal8Bit(backend->readAllStandardError())));
 }
 
 void RKFrontendTransmitter::writeRequest (RBackendRequest *request) {
