@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkrinterface.h  -  description
-                             -------------------
-    begin                : Fri Nov 1 2002
-    copyright            : (C) 2002 - 2018 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkrinterface.h - This file is part of the RKWard project. Created: Fri Nov 1 2002
+SPDX-FileCopyrightText: 2002-2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef RKRINTERFACE_H
 #define RKRINTERFACE_H
@@ -99,8 +89,11 @@ private:
 		RecordingCommandsUnfiltered
 	} command_logfile_mode;
 
-	void processHistoricalSubstackRequest (const QStringList &calllist, RCommand *parent_command);
-	QStringList processPlainGenericRequest (const QStringList &calllist);
+/** helper function to handle backend requests that (may) involve running additional R-"sub"-commands. TODO; This should probably be merged with processRBackendRequest.*/
+	void processHistoricalSubstackRequest (const QStringList &calllist, RCommand *parent_command, RBackendRequest *request);
+/** helper function to handle the bulk backend of requests that do not involve running sub-commands */
+	GenericRRequestResult processPlainGenericRequest (const QStringList &calllist);
+/** helper function to handle backend requests that do not inolve running sub-commands. */
 	void processRBackendRequest (RBackendRequest *request);
 
 /** A list of all commands that have entered, and not yet left, the backend thread */
