@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rksessionvars  -  description
-                             -------------------
-    begin                : Thu Sep 08 2011
-    copyright            : (C) 2011-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rksessionvars - This file is part of RKWard (https://rkward.kde.org). Created: Thu Sep 08 2011
+SPDX-FileCopyrightText: 2011-2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rksessionvars.h"
 
@@ -54,7 +44,7 @@ void RKSessionVars::setInstalledPackages (const QStringList &new_list) {
 	RK_TRACE (RBACKEND);
 
 	installed_packages = new_list;
-	emit (installedPackagesChanged ());
+	emit installedPackagesChanged();
 }
 
 void RKSessionVars::setRVersion (const QString& version_string) {
@@ -77,10 +67,10 @@ quint32 RKSessionVars::parseVersionString (const QString &version, QString *suff
 	int pos = -1;
 	int opos = 0;
 	for (int i = 3; i >= 0; --i) {
-		while (1) {
+		while (true) {
 			++pos;
 			if (!(pos < version.size () && version[pos].isDigit ())) {
-				int val = version.mid (opos, pos - opos).toInt ();
+				int val = version.midRef(opos, pos - opos).toInt();
 				if ((val < 0) || (val > 255) || (pos == opos)) {
 					RK_DEBUG (MISC, DL_ERROR, "Invalid version specification '%s'", qPrintable (version));
 					if (val > 255) val = 255;
