@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkconsole  -  description
-                             -------------------
-    begin                : Thu Aug 19 2004
-    copyright            : (C) 2004-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkconsole - This file is part of RKWard (https://rkward.kde.org). Created: Thu Aug 19 2004
+SPDX-FileCopyrightText: 2004-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "rkconsole.h"
 
 #include <qfont.h>
@@ -106,11 +96,6 @@ RKConsole::RKConsole (QWidget *parent, bool tool_window, const char *name) : RKM
 	view = doc->createView (this);
 	layout->addWidget (view);
 	view->setStatusBarEnabled (false);
-
-	KTextEditor::ConfigInterface *confint = qobject_cast<KTextEditor::ConfigInterface*> (view);
-	RK_ASSERT (view);
-	confint->setConfigValue ("dynamic-word-wrap", false);
-
 	setFocusProxy (view);
 	setFocusPolicy (Qt::StrongFocus);
 	
@@ -149,6 +134,12 @@ RKConsole::RKConsole (QWidget *parent, bool tool_window, const char *name) : RKM
 	setMetaInfo (shortCaption (), QUrl ("rkward://page/rkward_console"), RKSettings::PageConsole);
 	initializeActivationSignals ();
 	initializeActions (getPart ()->actionCollection ());
+	KTextEditor::ConfigInterface *confint = qobject_cast<KTextEditor::ConfigInterface*> (view);
+	RK_ASSERT(confint);
+	QAction* action = RKSettingsModuleConsole::showMinimap()->makeAction(this, i18n("Scrollbar minimap"), [confint](bool val) { confint->setConfigValue("scrollbar-minimap", val); });
+	getPart()->actionCollection()->addAction("view_show_minimap", action);
+	action = RKSettingsModuleConsole::wordWrap()->makeAction(this, i18n("Dynamic word wrap"), [confint](bool val) { confint->setConfigValue("dynamic-word-wrap", val); });
+	getPart()->actionCollection()->addAction("view_dynamic_word_wrap", action);
 
 	nprefix = "> ";
 	iprefix = "+ ";
@@ -173,6 +164,7 @@ RKConsole::RKConsole (QWidget *parent, bool tool_window, const char *name) : RKM
 RKConsole::~RKConsole () {
 	RK_TRACE (APP);
 
+	if (this == main_console) main_console = nullptr;
 	RKSettingsModuleConsole::saveCommandHistory (commands_history.getHistory ());
 }
 
@@ -198,7 +190,7 @@ QAction* RKConsole::addProxyAction (const QString& actionName, const QString& la
 		ret->setIcon (found->icon ());
 		ret->setIconText (found->iconText ());
 		ret->setToolTip (found->toolTip ());
-		ret->setStatusTip (found->statusTip ());
+		ret->setWhatsThis(found->statusTip ());
 		ret->setCheckable (found->isCheckable ());
 		ret->setChecked (found->isChecked ());
 		// TODO: ideally, we'd also relay enabledness, checked state, etc. That would probably require a separate class,
@@ -213,7 +205,7 @@ QAction* RKConsole::addProxyAction (const QString& actionName, const QString& la
 	}
 }
 
-void RKConsole::triggerEditAction (QString name) {
+void RKConsole::triggerEditAction (const QString &name) {
 	RK_TRACE (APP);
 
 	if (!kate_edit_actions) return;
@@ -476,11 +468,11 @@ void RKConsole::submitCommand () {
 			last_line_end = 0;
 			RK_ASSERT (false);
 		}
-		command.append (input_buffer.left (last_line_end));
-		if (last_line_end < (input_buffer.size () - 1)) {
-			input_buffer = input_buffer.mid (last_line_end + 1);
+		command.append(input_buffer.leftRef(last_line_end));
+		if (last_line_end < (input_buffer.size() - 1)) {
+			input_buffer = input_buffer.mid(last_line_end + 1);
 		} else {
-			input_buffer.clear ();
+			input_buffer.clear();
 		}
 	} else {
 		RK_ASSERT (!command.endsWith ('\n'));
@@ -541,10 +533,17 @@ void RKConsole::rCommandDone (RCommand *command) {
 	tryNextInBuffer ();
 }
 
-void RKConsole::newOutput (RCommand *, ROutput *output) {
+void RKConsole::newOutput (RCommand *command, ROutput *output) {
 	RK_TRACE (APP);
 
-	int start_line = doc->lines () -1;
+	int first_line = doc->lines () -1;
+	QString popped_line;
+	if (!command) {
+		// spontanteous R output, to be inserted _above_ the current command
+		// as a shortcut, we pop the last line, and reinsert in, later
+		popped_line = doc->line(doc->lines() - 1);
+		doc->removeLine(doc->lines() - 1);
+	}
 
 	// split by and handle carriage returns
 	const QString outstr = output->output;
@@ -567,11 +566,11 @@ void RKConsole::newOutput (RCommand *, ROutput *output) {
 	if (start_pos <= end_pos) doc->insertText (doc->documentEnd (), outstr.mid (start_pos, end_pos - start_pos + 1));
 
 	int end_line = doc->lines () -1;
-	if (output->type != ROutput::Output) {
+	if (output->type != ROutput::Output || (!command)) {
 		KTextEditor::MarkInterface *markiface = qobject_cast<KTextEditor::MarkInterface*> (doc);
 		RK_ASSERT (markiface);
-		for (int line = start_line; line < end_line; ++line) {
-			markiface->addMark (line, KTextEditor::MarkInterface::BreakpointActive);
+		for (int line = first_line; line < end_line; ++line) {
+			markiface->addMark (line, command ? KTextEditor::MarkInterface::BreakpointActive : KTextEditor::MarkInterface::BreakpointDisabled);
 		}
 	}
 
@@ -585,6 +584,11 @@ void RKConsole::newOutput (RCommand *, ROutput *output) {
 			view->setUpdatesEnabled (true);
 		}
 	}
+
+	if (!command) {
+		doc->insertLine(doc->lines(), popped_line);
+	}
+
 	cursorAtTheEnd ();
 }
 
@@ -613,8 +617,8 @@ void RKConsole::submitBatch (const QString &batch) {
 		QString line = currentEditingLine ();
 		int pos = currentCursorPositionInCommand ();
 		if (pos >= 0) {
-			setCurrentEditingLine (line.left (pos));
-			input_buffer.append (line.mid (pos));
+			setCurrentEditingLine(line.left(pos));
+			input_buffer.append(line.midRef(pos));
 		}
 	}
 	if (!current_command) tryNextInBuffer ();
@@ -744,12 +748,12 @@ QString RKConsole::cleanSelection (const QString &origin) {
 	ret.reserve (origin.length ());
 	QStringList lines = origin.split ('\n');
 	foreach (const QString& line, lines) {
-		if (line.startsWith (nprefix)) {
-			ret.append (line.mid (nprefix.length ()));
-		} else if (line.startsWith (iprefix)) {
-			ret.append (line.mid (iprefix.length ()));
+		if (line.startsWith(nprefix)) {
+			ret.append(line.midRef(nprefix.length()));
+		} else if (line.startsWith(iprefix)) {
+			ret.append(line.midRef(iprefix.length()));
 		} else {
-			ret.append (line);
+			ret.append(line);
 		}
 		ret.append ('\n');
 	}
@@ -860,7 +864,6 @@ void RKConsole::initializeActions (KActionCollection *ac) {
 
 	addProxyAction ("file_print", i18n ("Print Console"));
 	addProxyAction ("file_export_html");
-	addProxyAction ("view_dynamic_word_wrap");
 	addProxyAction ("view_inc_font_sizes");
 	addProxyAction ("view_dec_font_sizes");
 
@@ -906,6 +909,12 @@ void RKConsole::pipeCommandThroughConsoleLocal (const QString &command_string) {
 	previous_chunk_was_piped = true;
 }
 
+void RKConsole::insertSpontaneousROutput(ROutput* output) {
+	RK_TRACE (APP);
+	RK_ASSERT(!current_command);
+	newOutput(nullptr, output);
+}
+
 void RKConsole::contextMenuEvent (QContextMenuEvent * event) {
 	RK_TRACE (APP);
 
