@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkconsole  -  description
-                             -------------------
-    begin                : Thu Aug 19 2004
-    copyright            : (C) 2004-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkconsole - This file is part of the RKWard project. Created: Thu Aug 19 2004
+SPDX-FileCopyrightText: 2004-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKCONSOLE_H
 #define RKCONSOLE_H
 
@@ -75,6 +65,7 @@ public:
 	void setCommandHistory (const QStringList &new_history, bool append);
 	QStringList commandHistory () const { return commands_history.getHistory (); };
 	void addCommandToHistory (const QString& text) { commands_history.append (text); };
+	void insertSpontaneousROutput(ROutput *output);
 protected:
 /** Handle keystrokes before they reach the kate-part. Return TRUE if we want the kate-part to ignore it
 \param e the QKeyEvent */
@@ -138,7 +129,7 @@ friend class RKConsolePart;
 	QAction* paste_action;
 
 	KActionCollection *kate_edit_actions;
-	void triggerEditAction (QString name);
+	void triggerEditAction (const QString &name);
 	void setCursorClear (int line, int col);
 
 	void initializeActions (KActionCollection *ac);
