@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkward.h  -  description
-                             -------------------
-    begin                : Tue Oct 29 20:06:08 CET 2002
-    copyright            : (C) 2002-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkward.h - This file is part of the RKWard project. Created: Tue Oct 29 2002
+SPDX-FileCopyrightText: 2002-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef RKWARD_H
 #define RKWARD_H
@@ -124,6 +114,11 @@ public slots:
 /** open a new command editor (load given url) */
 	void slotOpenCommandEditor (const QUrl &url, const QString& encoding = QString ());
 
+/** create and show a new output window */
+	void slotNewOutput();
+/** load an output Window (ask for file to open) */
+	void slotOpenOutput();
+
 /** close current window (Windows->Close). */
 	void slotCloseWindow ();
 /** close all windows (Windows->Close All) */
@@ -141,18 +136,16 @@ private slots:
 private:
 /** Prompt for a local file to open, providing a choice of how to open the file (as R script, text, workspace, auto) */
 	void openAnyFile ();
-/** Opens a new workspace, without asking or closing anything. */
-	void openWorkspace (const QUrl &url);
 
 	QLabel* statusbar_r_status;
 	KSqueezedTextLabel* statusbar_cwd;
-	QLabel* statusbar_ready;
 	KParts::PartManager *part_manager;
 
 	// QAction pointers to enable/disable actions
-	QAction* fileOpen;
+	QAction* fileOpenScript;
+	QAction* fileOpenOutput;
 	KRecentFilesAction* fileOpenRecent;
-	
+
 	QAction* fileOpenWorkspace;
 	KRecentFilesAction* fileOpenRecentWorkspace;
 	QAction* fileSaveWorkspace;
@@ -162,6 +155,7 @@ private:
 	QAction* close_all_editors;
 	QAction* new_data_frame;
 	QAction* new_command_editor;
+	QAction* new_output;
 
 	QAction* window_close_all;
 	QAction* window_detach;
@@ -200,6 +194,7 @@ private:
 	bool merge_loads;
 
 	KatePluginIntegrationApp *katepluginintegration;
+	KXMLGUIClient *active_ui_buddy;
 };
 
 #endif // RKWARD_H
