@@ -1,19 +1,9 @@
-/***************************************************************************
-                          qtscriptbackend  -  description
-                             -------------------
-    begin                : Mon Sep 28 2009
-    copyright            : (C) 2009, 2010, 2012, 2014, 2015 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+qtscriptbackend - This file is part of RKWard (https://rkward.kde.org). Created: Mon Sep 28 2009
+SPDX-FileCopyrightText: 2009-2015 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "qtscriptbackend.h"
 
 #include <QTimer>
@@ -122,7 +112,7 @@ void QtScriptBackend::threadError (const QString &message) {
 
 	KMessageBox::error (0, i18n ("The QtScript-backend has reported an error:\n%1", message), i18n ("Scripting error"));
 
-	emit (haveError ());
+	emit haveError();
 	destroy ();
 }
 
@@ -135,7 +125,7 @@ void QtScriptBackend::commandDone (const QString &result) {
 void QtScriptBackend::needData (const QString &identifier, const int hint) {
 	RK_TRACE (PHP);
 
-	emit (requestValue (identifier, hint));
+	emit requestValue(identifier, hint);
 }
 
 
@@ -195,10 +185,9 @@ void QtScriptBackendThread::setData (const QVariant &data) {
 QVariant QtScriptBackendThread::getValue (const QString &identifier, const int hint) {
 	RK_TRACE (PHP);
 
-	emit (needData (identifier, hint));
-
+	emit needData(identifier, hint);
 	QVariant ret;
-	while (1) {
+	while (true) {
 		if (killed) return QVariant ();
 
 		mutex.lock ();
@@ -235,17 +224,31 @@ QVariant QtScriptBackendThread::getUiLabelPair (const QString &identifier) {
 	return getValue (identifier, RKStandardComponent::UiLabelPair);
 }
 
-bool QtScriptBackendThread::scriptError () {
+#ifdef USE_QJSENGINE
+bool QtScriptBackendThread::scriptError(const QJSValue &val) {
 	RK_TRACE (PHP);
 
+	if (!val.isError()) return false;
+
+	QString message = i18n("Script Error in %1, line %2: %3\nBacktrace:\n%4", val.property("fileName").toString(), val.property("lineNumber").toInt(), val.toString(), val.property("stack").toString());  // TODO: correct?
+	emit error(message);
+
+	return true;
+}
+#else
+bool QtScriptBackendThread::scriptError(const RKJSValue &val) {
+	RK_TRACE (PHP);
+	Q_UNUSED(val);
+
 	if (!engine.hasUncaughtException ()) return false;
 
 	QString message = i18n ("Script Error: %1\nBacktrace:\n%2", engine.uncaughtException ().toString (), engine.uncaughtExceptionBacktrace ().join ("\n"));
 	engine.clearExceptions ();
-	emit (error (message));
+	emit error(message);
 
 	return true;
 }
+#endif
 
 bool QtScriptBackendThread::includeFile (const QString &filename) {
 	RK_TRACE (PHP);
@@ -258,15 +261,16 @@ bool QtScriptBackendThread::includeFile (const QString &filename) {
 
 		QFile file (_filename);
 		if (!file.open (QIODevice::ReadOnly | QIODevice::Text)) {
-		emit (error (i18n ("The file \"%1\" (needed by \"%2\") could not be found. Please check your installation.", _filename, _scriptfile)));
+		emit error(i18n("The file \"%1\" (needed by \"%2\") could not be found. Please check your installation.", _filename, _scriptfile));
 		return false;
 	}
 
+#ifndef USE_QJSENGINE
 	// evaluate in global context
 	engine.currentContext ()->setActivationObject (engine.globalObject ());
-	QScriptValue result = engine.evaluate (QString::fromUtf8 (file.readAll ()), _filename);
-
-	if (scriptError ()) return false;
+#endif
+	RKJSValue result = engine.evaluate (QString::fromUtf8 (file.readAll ()), _filename);
+	if (scriptError(result)) return false;
 
 	return true;
 }
@@ -274,17 +278,16 @@ bool QtScriptBackendThread::includeFile (const QString &filename) {
 void QtScriptBackendThread::run () {
 	RK_TRACE (PHP);
 
-	QScriptValue backend_object = engine.newQObject (this);
+	RKJSValue backend_object = engine.newQObject (this);
 	engine.globalObject ().setProperty ("_RK_backend", backend_object);
 	RKMessageCatalogObject::addI18nToScriptEngine (&engine, catalog);
-	if (scriptError ()) return;
 
 #ifdef USE_Q_SCRIPT_PROGRAM
 	if (!RKPrecompiledQtScripts::loadCommonScript (&engine, _commonfile)) {
 		if (!engine.hasUncaughtException ()) {
 			emit error (i18n ("Could not open common script file \"%1\"", _commonfile));
 		} else {
-			scriptError ();
+			scriptError (QScriptValue());
 		}
 		return;
 	}
@@ -293,10 +296,10 @@ void QtScriptBackendThread::run () {
 #endif
 	if (!includeFile (_scriptfile)) return;
 
-	emit (commandDone ("startup complete"));
+	emit commandDone("startup complete");
 
 	QString command;
-	while (1) {
+	while (true) {
 		if (killed) return;
 		if (sleeping) {
 			sleep_mutex.lock ();
@@ -316,9 +319,9 @@ void QtScriptBackendThread::run () {
 		}
 
 		// do it!
-		QScriptValue result = engine.evaluate (command);
-		if (scriptError ()) return;
-		emit (commandDone (result.toString ()));
+		RKJSValue result = engine.evaluate (command);
+		if (scriptError(result)) return;
+		emit commandDone(result.toString());
 
 		command.clear ();
 	}
@@ -329,7 +332,7 @@ namespace RKPrecompiledQtScripts {
 	QMap<QString, QScriptProgram> compiled_includes;
 	QMutex compiled_includes_mutex;
 
-	bool loadCommonScript (QScriptEngine* engine, QString scriptfile) {
+	bool loadCommonScript (QScriptEngine* engine, const QString &scriptfile) {
 		RK_TRACE (PHP);
 
 		// NOTE: QScriptProgram cannot be evaluated concurrently in several threads (see https://bugreports.qt-project.org/browse/QTBUG-29246).
