@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rksettingsmodulecommandeditor  -  description
-                             -------------------
-    begin                : Tue Oct 23 2007
-    copyright            : (C) 2007-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rksettingsmodulecommandeditor - This file is part of the RKWard project. Created: Tue Oct 23 2007
+SPDX-FileCopyrightText: 2007-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKSETTINGSMODULECOMMANDEDITOR_H
 #define RKSETTINGSMODULECOMMANDEDITOR_H
 
@@ -21,11 +11,11 @@
 #include "../core/robject.h"
 
 class RKSpinBox;
-class QCheckBox;
 class QLineEdit;
 class QGroupBox;
 class QComboBox;
 class QGridLayout;
+namespace KTextEditor { class ConfigPage; }
 
 class RKCodeCompletionSettingsWidget;
 class RKCodeCompletionSettings {
@@ -33,8 +23,7 @@ public:
 	RKCodeCompletionSettings() {};
 	~RKCodeCompletionSettings() {};
 
-	void loadSettings(KConfigGroup &config) { group.loadConfig(config); };
-	void saveSettings(KConfigGroup &config) { group.saveConfig(config); };
+	void syncConfig(KConfigGroup &cg, RKConfigBase::ConfigSyncAction a) { group.syncConfig(cg, a); };
 
 	// NOTE: Don't insert values inbetween existing values, without also adjusting the sloppy config load/save/apply code
 	enum CompletionCategories {
@@ -79,19 +68,23 @@ public:
 private:
 	void makeCompletionTypeBoxes (const QStringList& labels, QGridLayout* layout);
 
-	RKSpinBox* auto_completion_min_chars_box;
-	RKSpinBox* auto_completion_timeout_box;
 	QGroupBox* auto_completion_enabled_box;
-	QCheckBox* auto_completion_cursor_activated_box;
-	QCheckBox* tabkey_invokes_completion_box;
-	QCheckBox* completion_type_enabled_box[RKCodeCompletionSettings::N_COMPLETION_CATEGORIES];
-	QComboBox* cursor_navigates_completions_box;
-	QComboBox* completion_list_member_operator_box;
-	QComboBox* completion_slot_operator_box;
-	QComboBox* completion_object_qualification_box;
 
 	RKCodeCompletionSettings *settings;
-	bool show_common;
+};
+
+class RKSettingsModuleKTextEditorConfigWrapper : public RKSettingsModule {
+public:
+	RKSettingsModuleKTextEditorConfigWrapper(RKSettings* gui, QWidget* parent, KTextEditor::ConfigPage* wrapped);
+	~RKSettingsModuleKTextEditorConfigWrapper();
+	void applyChanges() override;
+	void save(KConfig *) override { };
+	static void validateSettingsInteractive(QList<RKSetupWizardItem*>*) {};
+	QString caption() const override;
+	QString longCaption() const override;
+	QIcon icon() const override;
+private:
+	KTextEditor::ConfigPage* page;
 };
 
 /**
@@ -106,13 +99,12 @@ public:
 	~RKSettingsModuleCommandEditor ();
 	
 	void applyChanges () override;
-	void save (KConfig *config) override;
-
-	static void saveSettings (KConfig *config);
-	static void loadSettings (KConfig *config);
+	void save (KConfig *config) override { syncConfig(config, RKConfigBase::SaveConfig); };
+	static void syncConfig(KConfig *config, RKConfigBase::ConfigSyncAction);
 	static void validateSettingsInteractive (QList<RKSetupWizardItem*>*) {};
 
-	QString caption () override;
+	QString caption() const override;
+	QIcon icon() const override;
 
 	static const RKCodeCompletionSettings* completionSettings() { return &completion_settings; };
 
@@ -124,23 +116,20 @@ public:
 	static int maxNumRecentFiles () { return num_recent_files; };
 	static QString scriptFileFilter () { return script_file_filter; };
 	static bool matchesScriptFileFilter (const QString &filename);
-public slots:
-	void settingChanged ();
+
+	static QList<RKSettingsModuleKTextEditorConfigWrapper*> kateConfigPages(RKSettings* gui, QWidget* parent);
 private:
 	static RKCodeCompletionSettings completion_settings;
-	static bool autosave_enabled;
-	static bool autosave_keep;
-	static int autosave_interval;
+	static RKConfigValue<bool> autosave_enabled;
+	static RKConfigValue<bool> autosave_keep;
+	static RKConfigValue<int> autosave_interval;
 
 	RKCodeCompletionSettingsWidget *completion_settings_widget;
 	QGroupBox* autosave_enabled_box;
-	QCheckBox* autosave_keep_box;
-	RKSpinBox* autosave_interval_box;
-
-	RKSpinBox* num_recent_files_box;
 	QLineEdit* script_file_filter_box;
-	static int num_recent_files;
-	static QString script_file_filter;
+
+	static RKConfigValue<int> num_recent_files;
+	static RKConfigValue<QString> script_file_filter;
 };
 
 #endif
