@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rksettingsmodulegeneral  -  description
-                             -------------------
-    begin                : Fri Jul 30 2004
-    copyright            : (C) 2004-2018 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rksettingsmodulegeneral - This file is part of the RKWard project. Created: Fri Jul 30 2004
+SPDX-FileCopyrightText: 2004-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKSETTINGSMODULEGENERALFILES_H
 #define RKSETTINGSMODULEGENERALFILES_H
 
@@ -22,7 +12,6 @@
 
 class GetFileNameWidget;
 class QComboBox;
-class QCheckBox;
 class QButtonGroup;
 class RKSpinBox;
 
@@ -55,13 +44,12 @@ public:
 	};
 
 	void applyChanges () override;
-	void save (KConfig *config) override;
-
-	static void saveSettings (KConfig *config);
-	static void loadSettings (KConfig *config);
+	void save(KConfig *config) override { syncConfig(config, RKConfigBase::SaveConfig); };
+	static void syncConfig(KConfig *config, RKConfigBase::ConfigSyncAction a);
 	static void validateSettingsInteractive (QList<RKSetupWizardItem*>*) {};
 
-	QString caption () override;
+	QString caption() const override;
+	QIcon icon() const override;
 
 /// returns the directory-name where the logfiles should reside
 	static QString &filesPath () { return files_path; };
@@ -96,6 +84,7 @@ public:
 		RKWardConfig_0_6_3,
 		RKWardConfig_0_6_4,
 		RKWardConfig_0_7_1,
+		RKWardConfig_0_7_3,
 		RKWardConfig_Next,		/**< add new configuration versions above / before this entry */
 		RKWardConfig_Latest = RKWardConfig_Next - 1
 	};
@@ -109,34 +98,26 @@ public:
 	static bool rkwardVersionChanged () { return rkward_version_changed; };
 	/** Returns true, if rkward seems to have started from a different path than on the previous run. */
 	static bool installationMoved () { return installation_moved; };
-public slots:
-	void settingChanged ();
 private:
 	GetFileNameWidget *files_choser;
-	QComboBox *startup_action_choser;
 	QButtonGroup *workplace_save_chooser;
-	QCheckBox *cd_to_workspace_dir_on_load_box;
-	QCheckBox *show_help_on_startup_box;
-	RKSpinBox *warn_size_object_edit_box;
-	QComboBox *mdi_focus_policy_chooser;
-	QComboBox *initial_dir_chooser;
 	GetFileNameWidget *initial_dir_custom_chooser;
 
-	static StartupDialog::Result startup_action;
+	static RKConfigValue<StartupDialog::Result, int> startup_action;
 	static QString files_path;
 /** since changing the files_path can not easily be done while in an active session, the setting should only take effect on the next start. This string stores a changed setting, while keeping the old one intact as long as RKWard is running */
-	static QString new_files_path;
-	static WorkplaceSaveMode workplace_save_mode;
-	static bool cd_to_workspace_dir_on_load;
-	static bool show_help_on_startup;
-	static int warn_size_object_edit;
-	static RKMDIFocusPolicy mdi_focus_policy;
-	static RKWardConfigVersion stored_config_version;
-	static bool config_exists;
-	static InitialDirectory initial_dir;
-	static QString initial_dir_specification;
-	static bool rkward_version_changed;
+	static RKConfigValue<QString> new_files_path;
+	static RKConfigValue<WorkplaceSaveMode, int> workplace_save_mode;
+	static RKConfigValue<bool> cd_to_workspace_dir_on_load;
+	static RKConfigValue<bool> show_help_on_startup;
+	static RKConfigValue<int> warn_size_object_edit;
+	static RKConfigValue<RKMDIFocusPolicy, int> mdi_focus_policy;
+	static RKConfigValue<InitialDirectory, int> initial_dir;
+	static RKConfigValue<QString> initial_dir_specification;
 	static QString previous_rkward_data_dir;
+	static RKWardConfigVersion stored_config_version;
+	static bool rkward_version_changed;
+	static bool config_exists;
 	static bool installation_moved;
 	static QUrl generic_filedialog_start_url;
 };
