@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rksettingsmoduleplugins  -  description
-                             -------------------
-    begin                : Wed Jul 28 2004
-    copyright            : (C) 2004-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rksettingsmoduleplugins - This file is part of RKWard (https://rkward.kde.org). Created: Wed Jul 28 2004
+SPDX-FileCopyrightText: 2004-2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "rksettingsmoduleplugins.h"
 
 #include <KLocalizedString>
@@ -30,6 +20,7 @@
 #include <QVBoxLayout>
 #include <QPushButton>
 #include <QFileDialog>
+#include <QIcon>
 
 #include "../rkward.h"
 #include "../rkglobals.h"
@@ -45,10 +36,10 @@
 
 // static members
 QList<RKSettingsModulePlugins::PluginMapStoredInfo> RKSettingsModulePlugins::known_plugin_maps;
-RKSettingsModulePlugins::PluginPrefs RKSettingsModulePlugins::interface_pref;
-bool RKSettingsModulePlugins::show_code;
-int RKSettingsModulePlugins::code_size;
-int RKSettingsModulePlugins::side_preview_width;
+RKConfigValue<RKSettingsModulePlugins::PluginPrefs, int> RKSettingsModulePlugins::interface_pref {"Interface Preferences", RKSettingsModulePlugins::PreferRecommended};
+RKConfigValue<bool> RKSettingsModulePlugins::show_code {"Code display default", false};
+RKConfigValue<int> RKSettingsModulePlugins::code_size {"Code display size", 250};
+RKConfigValue<int> RKSettingsModulePlugins::side_preview_width {"Other preview size", 250};
 
 RKSettingsModulePlugins::RKSettingsModulePlugins (RKSettings *gui, QWidget *parent) : RKSettingsModule (gui, parent) {
 	RK_TRACE (SETTINGS);
@@ -97,9 +88,14 @@ void RKSettingsModulePlugins::settingChanged () {
 	change ();
 }
 
-QString RKSettingsModulePlugins::caption () {
-	RK_TRACE (SETTINGS);
-	return (i18n ("RKWard Plugins"));
+QString RKSettingsModulePlugins::caption() const {
+	RK_TRACE(SETTINGS);
+	return(i18n("RKWard Plugins"));
+}
+
+QIcon RKSettingsModulePlugins::icon() const {
+	RK_TRACE(SETTINGS);
+	return QIcon::fromTheme("plugins");
 }
 
 void RKSettingsModulePlugins::applyChanges () {
@@ -108,7 +104,7 @@ void RKSettingsModulePlugins::applyChanges () {
 	interface_pref = static_cast<PluginPrefs> (button_group->checkedId ());
 }
 
-RKSettingsModulePlugins::PluginMapList RKSettingsModulePlugins::setPluginMaps (const RKSettingsModulePlugins::PluginMapList new_list) {
+RKSettingsModulePlugins::PluginMapList RKSettingsModulePlugins::setPluginMaps (const RKSettingsModulePlugins::PluginMapList &new_list) {
 	RK_TRACE (SETTINGS);
 
 	known_plugin_maps = new_list;
@@ -123,82 +119,75 @@ void RKSettingsModulePlugins::configurePluginmaps () {
 	RKLoadLibsDialog::showPluginmapConfig (this, commandChain ());
 }
 
-void RKSettingsModulePlugins::save (KConfig *config) {
-	RK_TRACE (SETTINGS);
-	saveSettings (config);
-}
+void savePluginMaps(KConfigGroup &cg, const RKSettingsModulePlugins::PluginMapList &known_plugin_maps) {
+	RK_TRACE(SETTINGS);
 
-void RKSettingsModulePlugins::saveSettings (KConfig *config) {
-	RK_TRACE (SETTINGS);
-
-	KConfigGroup cg = config->group ("Plugin Settings");
-	cg.deleteGroup ("Known Plugin maps");	// always start from scratch to remove cruft from pluginmaps
-	KConfigGroup pmg = cg.group ("Known Plugin maps");
+	cg.deleteGroup("Known Plugin maps");	// always start from scratch to remove cruft from pluginmaps
+	KConfigGroup pmg = cg.group("Known Plugin maps");
 	QStringList all_known_maps;
 	for (int i = 0; i < known_plugin_maps.size (); ++i) {
-		const PluginMapStoredInfo &inf = known_plugin_maps[i];
+		const RKSettingsModulePlugins::PluginMapStoredInfo &inf = known_plugin_maps[i];
 		KConfigGroup ppmg = pmg.group (inf.filename);
-		ppmg.writeEntry ("Active", inf.active);
-		ppmg.writeEntry ("Broken", inf.broken_in_this_version);
-		ppmg.writeEntry ("Quirky", inf.quirky_in_this_version);
-		ppmg.writeEntry ("timestamp", inf.last_modified);
-		ppmg.writeEntry ("id", inf.id);
-		ppmg.writeEntry ("priority", inf.priority);
-		all_known_maps.append (inf.filename);
+		ppmg.writeEntry("Active", inf.active);
+		ppmg.writeEntry("Broken", inf.broken_in_this_version);
+		ppmg.writeEntry("Quirky", inf.quirky_in_this_version);
+		ppmg.writeEntry("timestamp", inf.last_modified);
+		ppmg.writeEntry("id", inf.id);
+		ppmg.writeEntry("priority", inf.priority);
+		all_known_maps.append(inf.filename);
 	}
 	// NOTE: The group list is always sorted alphabetically, which is why we need a separate list setting for saving info on order.
-	cg.writeEntry ("All known plugin maps", all_known_maps);
-
-	cg.writeEntry ("Interface Preferences", static_cast<int> (interface_pref));
-	cg.writeEntry ("Code display default", show_code);
-	cg.writeEntry ("Code display size", code_size);
-	cg.writeEntry ("Other preview size", side_preview_width);
+	cg.writeEntry("All known plugin maps", all_known_maps);
 }
 
-void RKSettingsModulePlugins::loadSettings (KConfig *config) {
+void RKSettingsModulePlugins::syncConfig(KConfig *config, RKConfigBase::ConfigSyncAction a) {
 	RK_TRACE (SETTINGS);
 
-	KConfigGroup cg = config->group ("Plugin Settings");
-	if (RKSettingsModuleGeneral::storedConfigVersion () < RKSettingsModuleGeneral::RKWardConfig_0_6_1) {
-		QStringList plugin_maps = cg.readEntry ("Plugin Maps", QStringList ());
-		QStringList kplugin_maps = cg.readEntry ("All known plugin maps", QStringList ());
-		for (int i = 0; i < kplugin_maps.size (); ++i) {
-			PluginMapStoredInfo inf (RKSettingsModuleGeneral::checkAdjustLoadedPath (kplugin_maps[i]));
-			inf.active = plugin_maps.contains (kplugin_maps[i]);	// comparing unadjusted path on purpose!
-			// state info will be properly initialized in fixPluginMapLists()
-			known_plugin_maps.append (inf);
-		}
+	KConfigGroup cg = config->group("Plugin Settings");
+	interface_pref.syncConfig(cg, a);
+	show_code.syncConfig(cg, a);
+	code_size.syncConfig(cg, a);
+	side_preview_width.syncConfig(cg, a);
+
+	if (a == RKConfigBase::SaveConfig) {
+		savePluginMaps(cg, known_plugin_maps);
 	} else {
-		KConfigGroup pmg = cg.group ("Known Plugin maps");
-		QStringList kplugin_maps = cg.readEntry ("All known plugin maps", QStringList ());
-		for (int i = 0; i < kplugin_maps.size (); ++i) {
-			KConfigGroup ppmg = pmg.group (kplugin_maps[i]);	// unadjusted path on purpose!
-			PluginMapStoredInfo inf (RKSettingsModuleGeneral::checkAdjustLoadedPath (kplugin_maps[i]));
-			inf.active = ppmg.readEntry ("Active", false);
-			// Pluginmaps which are broken with one version of RKWard may be alright with other versions. So reset flags, if version has changed.
-			inf.broken_in_this_version = ppmg.readEntry ("Broken", false) && !RKSettingsModuleGeneral::rkwardVersionChanged ();
-			inf.quirky_in_this_version = ppmg.readEntry ("Quirky", false) && !RKSettingsModuleGeneral::rkwardVersionChanged ();
-			inf.last_modified = ppmg.readEntry ("timestamp", QDateTime ());
-			inf.id = ppmg.readEntry ("id");
-			inf.priority = ppmg.readEntry ("priority", (int) PriorityMedium);
-			known_plugin_maps.append (inf);
+		if (RKSettingsModuleGeneral::storedConfigVersion () < RKSettingsModuleGeneral::RKWardConfig_0_6_1) {
+			QStringList plugin_maps = cg.readEntry ("Plugin Maps", QStringList ());
+			QStringList kplugin_maps = cg.readEntry ("All known plugin maps", QStringList ());
+			for (int i = 0; i < kplugin_maps.size (); ++i) {
+				PluginMapStoredInfo inf (RKSettingsModuleGeneral::checkAdjustLoadedPath (kplugin_maps[i]));
+				inf.active = plugin_maps.contains (kplugin_maps[i]);	// comparing unadjusted path on purpose!
+				// state info will be properly initialized in fixPluginMapLists()
+				known_plugin_maps.append (inf);
+			}
+		} else {
+			KConfigGroup pmg = cg.group ("Known Plugin maps");
+			QStringList kplugin_maps = cg.readEntry ("All known plugin maps", QStringList ());
+			for (int i = 0; i < kplugin_maps.size (); ++i) {
+				KConfigGroup ppmg = pmg.group (kplugin_maps[i]);	// unadjusted path on purpose!
+				PluginMapStoredInfo inf (RKSettingsModuleGeneral::checkAdjustLoadedPath (kplugin_maps[i]));
+				inf.active = ppmg.readEntry ("Active", false);
+				// Pluginmaps which are broken with one version of RKWard may be alright with other versions. So reset flags, if version has changed.
+				inf.broken_in_this_version = ppmg.readEntry ("Broken", false) && !RKSettingsModuleGeneral::rkwardVersionChanged ();
+				inf.quirky_in_this_version = ppmg.readEntry ("Quirky", false) && !RKSettingsModuleGeneral::rkwardVersionChanged ();
+				inf.last_modified = ppmg.readEntry ("timestamp", QDateTime ());
+				inf.id = ppmg.readEntry ("id");
+				inf.priority = ppmg.readEntry ("priority", (int) PriorityMedium);
+				known_plugin_maps.append (inf);
+			}
 		}
-	}
-	if (RKSettingsModuleGeneral::rkwardVersionChanged () || RKSettingsModuleGeneral::installationMoved ()) {
-		// if it is the first start this version or from a new path, scan the installation for new pluginmaps
-		// Note that in the case of installationMoved(), checkAdjustLoadedPath() has already kicked in, above, but rescanning is still useful
-		// e.g. if users have installed to a new location, because they had botched their previous installation
-		registerDefaultPluginMaps(AddIfNewAndDefault);
-	}
-	fixPluginMapLists ();	// removes any maps which don't exist any more
+		if (RKSettingsModuleGeneral::rkwardVersionChanged () || RKSettingsModuleGeneral::installationMoved ()) {
+			// if it is the first start this version or from a new path, scan the installation for new pluginmaps
+			// Note that in the case of installationMoved(), checkAdjustLoadedPath() has already kicked in, above, but rescanning is still useful
+			// e.g. if users have installed to a new location, because they had botched their previous installation
+			registerDefaultPluginMaps(AddIfNewAndDefault);
+		}
+		fixPluginMapLists ();	// removes any maps which don't exist any more
 
-	interface_pref = static_cast<PluginPrefs> (cg.readEntry ("Interface Preferences", static_cast<int> (PreferRecommended)));
-	show_code = cg.readEntry ("Code display default", false);
-	code_size = cg.readEntry ("Code display size", 250);
-	side_preview_width = cg.readEntry ("Other preview size", 250);
-
-	if (RKSettingsModuleGeneral::storedConfigVersion () <= RKSettingsModuleGeneral::RKWardConfig_Pre0_5_7) {
-		if (code_size == 40) code_size = 250;	// previous default untouched.
+		if (RKSettingsModuleGeneral::storedConfigVersion () <= RKSettingsModuleGeneral::RKWardConfig_Pre0_5_7) {
+			if (code_size == 40) code_size = 250;	// previous default untouched.
+		}
 	}
 }
 
@@ -484,7 +473,7 @@ QVariant RKSettingsModulePluginsModel::data (const QModelIndex& index, int role)
 
 Qt::ItemFlags RKSettingsModulePluginsModel::flags (const QModelIndex& index) const {
 	// RK_TRACE (SETTINGS);
-	Qt::ItemFlags flags = QAbstractItemModel::flags (index);
+	Qt::ItemFlags flags = QAbstractTableModel::flags (index);
 	if (index.isValid () && (index.column () == COLUMN_CHECKED)) {
 		if (plugin_maps[index.row ()].priority > RKSettingsModulePlugins::PriorityHidden) flags |= Qt::ItemIsUserCheckable | Qt::ItemIsEditable;
 	}
@@ -509,7 +498,7 @@ bool RKSettingsModulePluginsModel::setData (const QModelIndex& index, const QVar
 	if (role == Qt::CheckStateRole) {
 		if (index.isValid () && (index.column () == COLUMN_CHECKED)) {
 			plugin_maps[index.row ()].active = value.toBool ();
-			emit (dataChanged (index, index));
+			emit dataChanged(index, index);
 			return true;
 		}
 	}
@@ -528,7 +517,7 @@ void RKSettingsModulePluginsModel::insertNewStrings (int above_row) {
 		if (pos >= 0) {
 			if (!plugin_maps[pos].active) {
 				plugin_maps[pos].active = true;
-				emit (dataChanged (index (pos, 0), index (pos, COLUMN_COUNT - 1)));
+				emit dataChanged(index(pos, 0), index(pos, COLUMN_COUNT - 1));
 			}
 			files.removeAt (i);
 		}
