@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rksettingsmoduleplugins  -  description
-                             -------------------
-    begin                : Wed Jul 28 2004
-    copyright            : (C) 2004-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rksettingsmoduleplugins - This file is part of the RKWard project. Created: Wed Jul 28 2004
+SPDX-FileCopyrightText: 2004-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKSETTINGSMODULEPLUGINS_H
 #define RKSETTINGSMODULEPLUGINS_H
 
@@ -27,7 +17,6 @@
 class RKMultiStringSelectorV2;
 class RKSettingsModulePluginsModel;
 class QButtonGroup;
-class QCheckBox;
 class RKSpinBox;
 
 /** The settings-module for plugin specific settings
@@ -40,15 +29,15 @@ public:
 	~RKSettingsModulePlugins ();
 
 	void applyChanges () override;
-	void save (KConfig *config) override;
 
 	enum PluginPrefs { PreferDialog=0, PreferRecommended=1, PreferWizard=2 };
 
-	static void saveSettings (KConfig *config);
-	static void loadSettings (KConfig *config);
+	void save(KConfig *config) override { syncConfig(config, RKConfigBase::SaveConfig); };
+	static void syncConfig(KConfig *config, RKConfigBase::ConfigSyncAction a);
 	static void validateSettingsInteractive (QList<RKSetupWizardItem*>*) {};
 
-	QString caption () override;
+	QString caption() const override;
+	QIcon icon() const override;
 
 	/** @returns a list of active plugin maps */
 	static QStringList pluginMaps ();
@@ -108,17 +97,17 @@ private:
 	/** plugin maps which are not necessarily active, but have been encountered, before. @see plugin_maps */
 	static PluginMapList known_plugin_maps;
 
-	static PluginPrefs interface_pref;
-	static bool show_code;
-	static int code_size;
-	static int side_preview_width;
+	static RKConfigValue<PluginPrefs,int> interface_pref;
+	static RKConfigValue<bool> show_code;
+	static RKConfigValue<int> code_size;
+	static RKConfigValue<int> side_preview_width;
 
 /* TODO: This one is currently unused (leftover of GHNS-based plugin installation), but might still be of interest */
 	static QStringList findPluginMapsRecursive (const QString &basedir);
 	static void fixPluginMapLists ();
 friend class RKPluginMapSelectionWidget;
 /** Sets the new list of plugins. Potentially removes unreadable ones, and returns the effective list. */
-	static PluginMapList setPluginMaps (const PluginMapList new_list);
+	static PluginMapList setPluginMaps (const PluginMapList &new_list);
 };
 
 class RKSettingsModulePluginsModel : public QAbstractTableModel {
