@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rksettingsmoduler  -  description
-                             -------------------
-    begin                : Wed Jul 28 2004
-    copyright            : (C) 2004-2018 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rksettingsmoduler - This file is part of the RKWard project. Created: Wed Jul 28 2004
+SPDX-FileCopyrightText: 2004-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKSETTINGSMODULER_H
 #define RKSETTINGSMODULER_H
 
@@ -22,7 +12,6 @@
 #include <qstring.h>
 #include <qstringlist.h>
 
-class QCheckBox;
 class QComboBox;
 class QLineEdit;
 class MultiStringSelector;
@@ -41,14 +30,13 @@ public:
 	~RKSettingsModuleR ();
 
 	void applyChanges () override;
-	void save (KConfig *config) override;
-
-	static void saveSettings (KConfig *config);
-	static void loadSettings (KConfig *config);
+	void save(KConfig *config) override { syncConfig(config, RKConfigBase::SaveConfig); };
+	static void syncConfig(KConfig *config, RKConfigBase::ConfigSyncAction a);
 	static void validateSettingsInteractive (QList<RKSetupWizardItem*>*) {};
 
-	QString caption () override;
-	
+	QString caption() const override;
+	QIcon icon() const override;
+
 /** generate the commands needed to set the R run time options */
 	static QStringList makeRRunTimeOptionCommands ();
 
@@ -62,34 +50,25 @@ private slots:
 	void addPaths (QStringList *string_list);
 private:
 	QLineEdit *outdec_input;
-	QSpinBox *width_input;
-	QComboBox *warn_input;
-	QSpinBox *warningslength_input;
-	QSpinBox *maxprint_input;
-	QComboBox *keepsource_input;
-	QComboBox *keepsourcepkgs_input;
-	QSpinBox *expressions_input;
-	QSpinBox *digits_input;
-	QComboBox *checkbounds_input;
 	QComboBox *editor_input;
 	QComboBox *pager_input;
 	QTextEdit *further_input;
 	MultiStringSelector *addpaths_selector;
 
-	static QString options_outdec;
-	static int options_width;
-	static int options_warn;
-	static int options_warningslength;
-	static int options_maxprint;
-	static bool options_keepsource;
-	static bool options_keepsourcepkgs;
-	static int options_expressions;
-	static int options_digits;
-	static bool options_checkbounds;
-	static QString options_editor;
-	static QString options_pager;
-	static QString options_further;
-	static QStringList options_addpaths;
+	static RKConfigValue<QString> options_outdec;
+	static RKConfigValue<int> options_width;
+	static RKConfigValue<int> options_warn;
+	static RKConfigValue<int> options_warningslength;
+	static RKConfigValue<int> options_maxprint;
+	static RKConfigValue<bool> options_keepsource;
+	static RKConfigValue<bool> options_keepsourcepkgs;
+	static RKConfigValue<int> options_expressions;
+	static RKConfigValue<int> options_digits;
+	static RKConfigValue<bool> options_checkbounds;
+	static RKConfigValue<QString> options_editor;
+	static RKConfigValue<QString> options_pager;
+	static RKConfigValue<QString> options_further;
+	static RKConfigValue<QStringList> options_addpaths;
 
 // constants
 	static QString builtin_editor;
@@ -113,10 +92,8 @@ public:
 	~RKSettingsModuleRPackages ();
 
 	void applyChanges () override;
-	void save (KConfig *config) override;
-
-	static void saveSettings (KConfig *config);
-	static void loadSettings (KConfig *config);
+	void save(KConfig *config) override { syncConfig(config, RKConfigBase::SaveConfig); };
+	static void syncConfig(KConfig *config, RKConfigBase::ConfigSyncAction a);
 	static void validateSettingsInteractive (QList<RKSetupWizardItem*>*);
 
 /** generate the commands needed to set the R run time options */
@@ -133,7 +110,8 @@ public:
 /** returns the list of packages which are essential to rkward. This is hard-coded. */
 	static QStringList essentialPackages () { return essential_packages.split ("\n"); };
 
-	QString caption () override;
+	QString caption() const override;
+	QIcon icon() const override;
 public slots:
 	void settingChanged ();
 	void addLibLoc (QStringList *string_list);
@@ -145,16 +123,14 @@ private:
 	static QString libLocsCommand ();
 
 	MultiStringSelector *libloc_selector;
-	QCheckBox *archive_packages_box;
-	QCheckBox *source_packages_box;
 	MultiStringSelector *repository_selector;
 	QLineEdit* cran_mirror_input;
 
-	static QString cran_mirror_url;
-	static QStringList liblocs;
-	static bool archive_packages;
-	static bool source_packages;
-	static QStringList package_repositories;
+	static RKConfigValue<QString> cran_mirror_url;
+	static RKConfigValue<QStringList> liblocs;
+	static RKConfigValue<bool> archive_packages;
+	static RKConfigValue<bool> source_packages;
+	static RKConfigValue<QStringList> package_repositories;
 
 	friend class RInterface;
 	static QString r_libs_user;
