@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rcontrolwindow  -  description
-                             -------------------
-    begin                : Wed Oct 12 2005
-    copyright            : (C) 2005, 2007, 2009 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rcontrolwindow - This file is part of RKWard (https://rkward.kde.org). Created: Wed Oct 12 2005
+SPDX-FileCopyrightText: 2005-2009 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rcontrolwindow.h"
 
