@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkcodecompletion  -  description
-                             -------------------
-    begin                : Thu Feb 21 2019
-    copyright            : (C) 2004-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkcodecompletion - This file is part of the RKWard project. Created: Thu Feb 21 2019
+SPDX-FileCopyrightText: 2004-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKCODECOMPLETION_H
 #define RKCODECOMPLETION_H
 
@@ -80,7 +70,6 @@ private:
 	KTextEditor::Range argname_range;
 
 	bool update_call;
-	bool keep_active;
 	bool user_triggered;
 	bool ignore_next_trigger;
 	QString prefix;
