@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkcommandlog  -  description
-                             -------------------
-    begin                : Sun Nov 3 2002
-    copyright            : (C) 2002, 2004, 2005 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkcommandlog - This file is part of RKWard (https://rkward.kde.org). Created: Sun Nov 3 2002
+SPDX-FileCopyrightText: 2002-2010 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkcommandlog.h"
 
@@ -246,11 +236,11 @@ RKCommandLogView::~RKCommandLogView () {
 	RK_TRACE (APP);
 }
 
-void RKCommandLogView::contextMenuEvent (QContextMenuEvent *event) {
-	RK_TRACE (APP);
+void RKCommandLogView::contextMenuEvent(QContextMenuEvent *event) {
+	RK_TRACE(APP);
 
-	emit (popupMenuRequest (event->globalPos ()));
-	event->accept ();
+	emit popupMenuRequest(event->globalPos());
+	event->accept();
 }
 
 void RKCommandLogView::selectAll () {
