@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkdebugconsole  -  description
-                             -------------------
-    begin                : Wed Oct 19 2011
-    copyright            : (C) 2011 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkdebugconsole - This file is part of RKWard (https://rkward.kde.org). Created: Wed Oct 19 2011
+SPDX-FileCopyrightText: 2011 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkdebugconsole.h"
 
@@ -163,13 +153,13 @@ void RKDebugConsole::sendReply (const QString &reply) {
 	RKDebugHandler::instance ()->submitDebugString (reply);
 }
 
-bool RKDebugConsole::close (bool also_delete) {
+bool RKDebugConsole::close (CloseWindowMode ask_save) {
 	RK_TRACE (APP);
 
 	if (RKDebugHandler::instance ()->state () != RKDebugHandler::NotInDebugger) {
 		KMessageBox::sorry (this, i18n ("This window cannot be closed, while a debugger is active. If you have no idea what this means, and you want to get out, press the 'Cancel' button on the right hand side of this window."));
 		return false;
 	}
-	return RKMDIWindow::close (also_delete);
+	return RKMDIWindow::close (ask_save);
 }
 
