@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkhtmlwindow  -  description
-                             -------------------
-    begin                : Wed Oct 12 2005
-    copyright            : (C) 2005-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkhtmlwindow - This file is part of RKWard (https://rkward.kde.org). Created: Wed Oct 12 2005
+SPDX-FileCopyrightText: 2005-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "rkhtmlwindow.h"
 
 #include <KLocalizedString>
@@ -24,6 +14,7 @@
 #include <kio/job.h>
 #include <kservice.h>
 #include <kcodecaction.h>
+#include <KColorScheme>
 
 #include <qfileinfo.h>
 #include <qwidget.h>
@@ -34,6 +25,7 @@
 #include <QHostInfo>
 #include <QPrintDialog>
 #include <QMenu>
+#include <QFileDialog>
 #include <QTextCodec>
 #include <QFontDatabase>
 #include <QTemporaryFile>
@@ -60,6 +52,7 @@
 #include "../misc/rkprogresscontrol.h"
 #include "../misc/rkmessagecatalog.h"
 #include "../misc/rkfindbar.h"
+#include "../misc/rkoutputdirectory.h"
 #include "../plugin/rkcomponentmap.h"
 #include "../windows/rkworkplace.h"
 #include "../windows/rkworkplaceview.h"
@@ -76,6 +69,8 @@ class RKWebPage : public KWebPage {
 #	include <QWebEngineView>
 #	include <QWebEngineSettings>
 #	include <QWebEngineProfile>
+#	include <QWebEngineScript>
+#	include <QWebEngineScriptCollection>
 class RKWebPage : public QWebEnginePage {
 #endif
 	Q_OBJECT
@@ -194,7 +189,7 @@ protected:
 
 		if (cururl.matches (navurl, QUrl::NormalizePathSegments | QUrl::StripTrailingSlash)) {
 			RK_DEBUG (APP, DL_DEBUG, "Page internal navigation request from %s to %s", qPrintable (cururl.toString ()), qPrintable (navurl.toString ()));
-			emit (pageInternalNavigation (navurl));
+			emit pageInternalNavigation(navurl);
 			return true;
 		}
 
@@ -284,12 +279,10 @@ private:
 
 
 RKWebPage* RKHTMLWindow::new_window = nullptr;
-
 RKHTMLWindow::RKHTMLWindow (QWidget *parent, WindowMode mode) : RKMDIWindow (parent, RKMDIWindow::HelpWindow) {
 	RK_TRACE (APP);
 
 	current_cache_file = 0;
-
 	QVBoxLayout* layout = new QVBoxLayout (this);
 	layout->setContentsMargins (0, 0, 0, 0);
 	view = new RKWebView (this);
@@ -312,6 +305,31 @@ RKHTMLWindow::RKHTMLWindow (QWidget *parent, WindowMode mode) : RKMDIWindow (par
 		QWebEngineProfile::defaultProfile ()->installUrlSchemeHandler ("help", new RKWebEngineKIOForwarder (RKWardMainWindow::getMain()));
 	}
 #endif
+	// Apply current color scheme to page. This needs support in the CSS of the page, so will only work for RKWard help and output pages.
+	// Note that the CSS in those pages also has "automatic" support for dark mode ("prefers-color-scheme: dark"; but see https://bugreports.qt.io/browse/QTBUG-89753), however, 
+	// for a seamless appearance, the only option is to set the theme colors dynamically, via javascript.
+	auto scheme = KColorScheme(QPalette::Normal);
+	QString color_scheme_js = QStringLiteral("function rksetcolor(name, value) { document.querySelector(':root').style.setProperty(name, value); }\n"
+	                                                "rksetcolor('--regular-text-color', '%1');\n"
+	                                                "rksetcolor('--background-color', '%2');\n"
+	                                                "rksetcolor('--header-color', '%3');\n"
+	                                                "rksetcolor('--anchor-color', '%4');").arg(scheme.foreground().color().name(), scheme.background().color().name(), scheme.foreground(KColorScheme::VisitedText).color().name(), scheme.foreground(KColorScheme::LinkText).color().name());
+#ifdef NO_QT_WEBENGINE
+	connect(page, &RKWebPage::loadFinished, [this, color_scheme_js](){
+		page->mainFrame()->evaluateJavaScript(color_scheme_js);
+	});
+#else
+	auto p = QWebEngineProfile::defaultProfile();
+	QWebEngineScript fix_color_scheme;
+	QString id = QStringLiteral("fix_color_scheme");
+	p->scripts()->remove(p->scripts()->findScript(id));  // remove any existing variant of the script. It might have been created for the wrong theme.
+	fix_color_scheme.setName(id);
+	fix_color_scheme.setInjectionPoint(QWebEngineScript::DocumentReady);
+	fix_color_scheme.setSourceCode(color_scheme_js);
+	p->scripts()->insert(fix_color_scheme);
+	//page->setBackgroundColor(scheme.background().color());  // avoids brief white blink while loading, but is too risky on pages that are not dark scheme aware.
+#endif
+
 	layout->addWidget (findbar);
 	findbar->hide ();
 	connect (findbar, &RKFindBar::findRequest, this, &RKHTMLWindow::findRequest);
@@ -330,7 +348,7 @@ RKHTMLWindow::RKHTMLWindow (QWidget *parent, WindowMode mode) : RKMDIWindow (par
 #ifdef NO_QT_WEBENGINE
 	connect (page, &QWebPage::downloadRequested, [this](const QNetworkRequest &request) { page->downloadUrl (request.url ()); });
 #else
-	connect (page->profile (), &QWebEngineProfile::downloadRequested, [this](QWebEngineDownloadItem* item) {
+	connect (page->profile (), &QWebEngineProfile::downloadRequested, this, [this](QWebEngineDownloadItem* item) {
 		QString path = QFileDialog::getSaveFileName (this, i18n ("Save as"), item->path ());
 		if (path.isEmpty ()) return;
 		item->setPath (path);
@@ -432,10 +450,34 @@ void RKHTMLWindow::slotPrint () {
 	delete dlg;
 }
 
-void RKHTMLWindow::slotSave () {
-	RK_TRACE (APP);
+void RKHTMLWindow::slotExport() {
+	RK_TRACE(APP);
 
-	page->downloadUrl (page->url ());
+	page->downloadUrl(page->url());
+}
+
+void RKHTMLWindow::slotSave() {
+	RK_TRACE(APP);
+	RK_ASSERT(dir);
+	dir->save(dir->filename());
+}
+
+void RKHTMLWindow::slotSaveAs() {
+	RK_TRACE (APP);
+	RK_ASSERT(dir);
+	dir->save();
+}
+
+void RKHTMLWindow::slotRevert() {
+	RK_TRACE (APP);
+	RK_ASSERT(dir);
+	dir->revert();
+}
+
+void RKHTMLWindow::slotActivate() {
+	RK_TRACE (APP);
+	RK_ASSERT(dir);
+	dir->activate();
 }
 
 void RKHTMLWindow::openLocationFromHistory (VisitedLocation &loc) {
@@ -558,6 +600,11 @@ bool RKHTMLWindow::openURL (const QUrl &url) {
 
 			current_url = url;	// needs to be set before registering
 			RKOutputWindowManager::self ()->registerWindow (this);
+			dir = RKOutputDirectory::findOutputByWorkPath(url.toLocalFile());
+			part->setOutputDirectoryActionsEnabled(dir != nullptr);
+			if (dir) {
+				connect(dir, &RKOutputDirectory::stateChange, this, &RKHTMLWindow::updateState);
+			}
 		}
 	}
 
@@ -604,10 +651,6 @@ bool RKHTMLWindow::openURL (const QUrl &url) {
 	return true;
 }
 
-QUrl RKHTMLWindow::url () {
-	return current_url;
-}
-
 void RKHTMLWindow::mimeTypeJobFail (KJob* job) {
 	RK_TRACE (APP);
 	
@@ -686,10 +729,31 @@ void RKHTMLWindow::changeURL (const QUrl &url) {
 	}
 }
 
+void RKHTMLWindow::updateState(){
+	updateCaption(current_url);
+}
+
 void RKHTMLWindow::updateCaption (const QUrl &url) {
 	RK_TRACE (APP);
 
-	if (window_mode == HTMLOutputWindow) setCaption (i18n ("Output %1", url.fileName ()));
+	if (window_mode == HTMLOutputWindow) {
+		if (dir) {
+			QString name = dir->caption();
+			QString mods;
+			if (dir->isActive()) mods.append(i18n("[Active]"));
+			// TODO: use icon(s), instead
+			bool mod = dir->isModifiedFast();
+			if (mod) mods.append("(*)");
+			if (!mods.isEmpty()) {
+				name.append(' ');
+				name.append(mods);
+			}
+			setCaption(name);
+			part->revert->setEnabled(mod);
+		} else {
+			setCaption (i18n ("Output %1", url.fileName ()));
+		}
+	}
 	else setCaption (url.fileName ());
 }
 
@@ -779,6 +843,12 @@ void RKHTMLWindow::fileDoesNotExistMessage () {
 void RKHTMLWindow::flushOutput () {
 	RK_TRACE (APP);
 
+	if (dir) {
+		dir->clear();
+		return;
+	}
+
+	// TODO: remove legacy code below, eventually
 	int res = KMessageBox::questionYesNo (this, i18n ("Do you really want to clear the output? This will also remove all image files used in the output. It will not be possible to restore it."), i18n ("Flush output?"));
 	if (res==KMessageBox::Yes) {
 		QFile out_file (current_url.toLocalFile ());
@@ -833,12 +903,13 @@ void RKHTMLWindowPart::initActions () {
 	actionCollection ()->addAction (KStandardAction::SelectAll, "select_all", window->view->pageAction (RKWebPage::SelectAll), SLOT (trigger()));
 	// unfortunately, this will only affect the default encoding, not necessarily the "real" encoding
 	KCodecAction *encoding = new KCodecAction (QIcon::fromTheme("character-set"), i18n ("Default &Encoding"), this, true);
-	encoding->setStatusTip (i18n ("Set the encoding to assume in case no explicit encoding has been set in the page or in the HTTP headers."));
+	encoding->setWhatsThis(i18n ("Set the encoding to assume in case no explicit encoding has been set in the page or in the HTTP headers."));
 	actionCollection ()->addAction ("view_encoding", encoding);
 	connect (encoding, static_cast<void (KCodecAction::*)(QTextCodec *)>(&KCodecAction::triggered), window, &RKHTMLWindow::setTextEncoding);
 
-	print = actionCollection ()->addAction (KStandardAction::Print, "print_html", window, SLOT (slotPrint()));
-	save_page = actionCollection ()->addAction (KStandardAction::Save, "save_html", window, SLOT (slotSave()));
+	print = actionCollection()->addAction(KStandardAction::Print, "print_html", window, SLOT (slotPrint()));
+	export_page = actionCollection()->addAction("save_html", new QAction(QIcon::fromTheme("file-save"), i18n("Export Page as HTML"), this));
+	connect(export_page, &QAction::triggered, window, &RKHTMLWindow::slotExport);
 
 	run_selection = RKStandardActions::runCurrent (window, window, SLOT (runSelection()));
 
@@ -850,11 +921,25 @@ void RKHTMLWindowPart::initActions () {
 	forward->setEnabled (false);
 
 	// output window actions
+	window->file_save_action = actionCollection()->addAction(KStandardAction::Save, window, SLOT(slotSave()));
+	window->file_save_action->setText(i18n("Save Output"));
+	window->file_save_as_action = actionCollection()->addAction(KStandardAction::SaveAs, window, SLOT(slotSaveAs()));
+	window->file_save_action->setText(i18n("Save Output As"));
+
 	outputFlush = actionCollection ()->addAction ("output_flush", window, SLOT (flushOutput()));
-	outputFlush->setText (i18n ("&Flush Output"));
+	outputFlush->setText (i18n ("&Clear Output"));
 	outputFlush->setIcon (QIcon::fromTheme("edit-delete"));
 
-	outputRefresh = actionCollection ()->addAction ("output_refresh", window->page->action (RKWebPage::Reload));
+	outputRefresh = actionCollection()->addAction("output_refresh", window->page->action(RKWebPage::Reload));
+
+	revert = actionCollection()->addAction("output_revert", window, SLOT(slotRevert()));
+	revert->setText(i18n("&Revert to last saved state"));
+	revert->setIcon(QIcon::fromTheme("edit-undo"));
+
+	activate = actionCollection()->addAction("output_activate", window, SLOT(slotActivate()));
+	activate->setText(i18n("Set Output as &Active"));
+	activate->setIcon(QIcon::fromTheme("emblem-favorite"));
+	activate->setWhatsThis(i18n("Set this output as the file to append output to."));
 
 	actionCollection ()->addAction (KStandardAction::Find, "find", window->findbar, SLOT (activate()));
 	QAction* findAhead = actionCollection ()->addAction ("find_ahead", new QAction (i18n ("Find as you type"), this));
@@ -864,22 +949,29 @@ void RKHTMLWindowPart::initActions () {
 	actionCollection ()->addAction (KStandardAction::FindPrev, "find_previous", window->findbar, SLOT (backward()));
 }
 
-void RKHTMLWindowPart::setOutputWindowSkin () {
-	RK_TRACE (APP);
+void RKHTMLWindowPart::setOutputDirectoryActionsEnabled(bool enable) {
+	RK_TRACE(APP);
 
-	print->setText (i18n ("Print output"));
-	save_page->setText (i18n ("Save Output as HTML"));
-	setXMLFile ("rkoutputwindow.rc");
-	run_selection->setVisible (false);
+	window->file_save_action->setVisible(enable);
+	window->file_save_as_action->setVisible(enable);
+	revert->setVisible(enable);
+	activate->setVisible(enable);
 }
 
-void RKHTMLWindowPart::setHelpWindowSkin () {
-	RK_TRACE (APP);
+void RKHTMLWindowPart::setOutputWindowSkin() {
+	RK_TRACE(APP);
 
-	print->setText (i18n ("Print page"));
-	save_page->setText (i18n ("Export page as HTML"));
-	setXMLFile ("rkhelpwindow.rc");
-	run_selection->setVisible (true);
+	print->setText(i18n("Print output"));
+	setXMLFile("rkoutputwindow.rc");
+	run_selection->setVisible(false);
+}
+
+void RKHTMLWindowPart::setHelpWindowSkin() {
+	RK_TRACE(APP);
+
+	print->setText(i18n("Print page"));
+	setXMLFile("rkhelpwindow.rc");
+	run_selection->setVisible(true);
 }
 
 //////////////////////////////////////////
@@ -1086,7 +1178,7 @@ QString RKHelpRenderer::renderHelpFragment (QDomElement &fragment) {
 	int npos;
 	QString ret;
 	while ((npos = text.indexOf ("<link", pos)) >= 0) {
-		ret += text.mid (pos, npos - pos);
+		ret += text.midRef(pos, npos - pos);
 
 		QString href;
 		int href_start = text.indexOf (" href=\"", npos + 5);
@@ -1106,14 +1198,14 @@ QString RKHelpRenderer::renderHelpFragment (QDomElement &fragment) {
 		ret += prepareHelpLink (href, linktext);
 		pos = end;
 	}
-	ret += text.mid (pos);
+	ret += text.midRef(pos);
 
 	if (component_xml) {
 		text = ret;
 		ret.clear ();
 		pos = 0;
 		while ((npos = text.indexOf ("<label ", pos)) >= 0) {
-			ret += text.mid (pos, npos - pos);
+			ret += text.midRef(pos, npos - pos);
 
 			QString id;
 			int id_start = text.indexOf ("id=\"", npos + 6);
@@ -1125,7 +1217,7 @@ QString RKHelpRenderer::renderHelpFragment (QDomElement &fragment) {
 			}
 			ret += resolveLabel (id);
 		}
-		ret += text.mid (pos);
+		ret += text.midRef(pos);
 	}
 
 	RK_DEBUG (APP, DL_DEBUG, "%s", qPrintable (ret));
@@ -1166,7 +1258,7 @@ QString RKHelpRenderer::prepareHelpLink (const QString &href, const QString &tex
 	return (ret + "</a>");
 }
 
-QString RKHelpRenderer::componentPathToId (QString path) {
+QString RKHelpRenderer::componentPathToId (const QString &path) {
 	RK_TRACE (APP);
 
 	QStringList path_segments = path.split ('/', QString::SkipEmptyParts);
@@ -1178,7 +1270,7 @@ QString RKHelpRenderer::componentPathToId (QString path) {
 	return (path_segments.join ("::"));
 }
 
-RKComponentHandle *RKHelpRenderer::componentPathToHandle (QString path) {
+RKComponentHandle *RKHelpRenderer::componentPathToHandle (const QString &path) {
 	RK_TRACE (APP);
 
 	return (RKComponentMap::getComponentHandle (componentPathToId (path)));
@@ -1202,6 +1294,10 @@ void RKHelpRenderer::writeHTML (const QString& string) {
 /////////////////////////////////////
 /////////////////////////////////////
 
+#include <QDir>
+#include <QFileInfo>
+#include <QCryptographicHash>
+#include <KIO/CopyJob>
 
 // static
 RKOutputWindowManager* RKOutputWindowManager::_self = 0;
@@ -1286,18 +1382,23 @@ void RKOutputWindowManager::setCurrentOutputPath (const QString &_path) {
 #endif
 	if (path == current_default_path) return;
 
-	if (!windows.contains (path)) {
-		RK_DEBUG (APP, DL_DEBUG, "starting to watch %s for changes, KDirWatch method %d", qPrintable (path), file_watcher->internalMethod ());
-		file_watcher->addFile (path);
+	auto old_win = windows.value(current_default_path);
+	auto new_win = windows.value(path);
+
+	if (!new_win) {
+		RK_DEBUG(APP, DL_DEBUG, "starting to watch %s for changes, KDirWatch method %d", qPrintable(path), file_watcher->internalMethod());
+		file_watcher->addFile(path);
 	}
-	if (!windows.contains (current_default_path)) {
-		if (!current_default_path.isEmpty ()) {
-			RK_DEBUG (APP, DL_DEBUG, "no longer watching %s for changes", qPrintable (current_default_path));
-			file_watcher->removeFile (current_default_path);
+	if (!old_win) {
+		if (!current_default_path.isEmpty()) {
+			RK_DEBUG(APP, DL_DEBUG, "no longer watching %s for changes", qPrintable(current_default_path));
+			file_watcher->removeFile(current_default_path);
 		}
 	}
 
 	current_default_path = path;
+	if (old_win) old_win->updateState();
+	if (new_win) new_win->updateState();
 }
 
 void RKOutputWindowManager::rewatchOutput () {
@@ -1307,20 +1408,10 @@ void RKOutputWindowManager::rewatchOutput () {
 	file_watcher->addFile (current_default_path);
 }
 
-QList<RKHTMLWindow*> RKOutputWindowManager::existingOutputWindows () const {
+QList<RKHTMLWindow*> RKOutputWindowManager::existingOutputWindows(const QString &path) const {
 	RK_TRACE (APP);
 
-	return (windows.values (current_default_path));
-}
-
-RKHTMLWindow* RKOutputWindowManager::newOutputWindow () {
-	RK_TRACE (APP);
-
-	RKHTMLWindow* current_output = new RKHTMLWindow (RKWorkplace::mainWorkplace ()->view (), RKHTMLWindow::HTMLOutputWindow);
-	current_output->openURL (QUrl::fromLocalFile (current_default_path));
-	RK_ASSERT (current_output->url ().toLocalFile () == current_default_path);
-
-	return current_output;
+	return (windows.values(path));
 }
 
 void RKOutputWindowManager::fileChanged (const QString &path) {
@@ -1336,25 +1427,33 @@ void RKOutputWindowManager::fileChanged (const QString &path) {
 
 	if (w) {
 		if (RKSettingsModuleOutput::autoRaise ()) w->activate ();
+		if (w->outputDirectory()) w->outputDirectory()->setKnownModified(true);
 	} else {
 		RK_ASSERT (path == current_default_path);
-		if (RKSettingsModuleOutput::autoShow ()) RKWorkplace::mainWorkplace ()->openOutputWindow (QUrl::fromUserInput (path, QString (), QUrl::AssumeLocalFile));
+		if (RKSettingsModuleOutput::autoShow ()) {
+			RKOutputDirectory* dir = RKOutputDirectory::findOutputByWorkPath(path);
+			if (dir) {
+				dir->view(true);
+			} else {
+				RKWorkplace::mainWorkplace()->openHTMLWindow(QUrl::fromUserInput(path, QString(), QUrl::AssumeLocalFile));
+			}
+		}
 	}
 }
 
-void RKOutputWindowManager::windowDestroyed (QObject *window) {
+void RKOutputWindowManager::windowDestroyed(QObject *window) {
 	RK_TRACE (APP);
 
 	// warning: Do not call any methods on the window. It is half-destroyed, already.
-	RKHTMLWindow *w = static_cast<RKHTMLWindow*> (window);
+	RKHTMLWindow *w = static_cast<RKHTMLWindow*>(window);
 
-	QString path = windows.key (w);
-	windows.remove (path, w);
+	QString path = windows.key(w);
+	windows.remove(path, w);
 
 	// if there are no further windows for this file, stop listening
-	if ((path != current_default_path) && (!windows.contains (path))) {
-		RK_DEBUG (APP, DL_DEBUG, "no longer watching %s for changes", qPrintable (path));
-		file_watcher->removeFile (path);
+	if ((path != current_default_path) && (!windows.contains(path))) {
+		RK_DEBUG(APP, DL_DEBUG, "no longer watching %s for changes", qPrintable(path));
+		file_watcher->removeFile(path);
 	}
 }
 
