@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkhtmlwindow  -  description
-                             -------------------
-    begin                : Wed Oct 12 2005
-    copyright            : (C) 2005-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkhtmlwindow - This file is part of the RKWard project. Created: Wed Oct 12 2005
+SPDX-FileCopyrightText: 2005-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef RKHTMLWINDOW_H
 #define RKHTMLWINDOW_H
@@ -36,8 +26,10 @@ class RKHTMLWindowPart;
 class QTemporaryFile;
 class RKHTMLWindow;
 class RKFindBar;
+class RCommandChain;
 class RKWebPage;
 class RKWebView;
+class RKOutputDirectory;
 
 /**
 	\brief Show html files.
@@ -73,14 +65,20 @@ public:
 
 	bool isModified () override;
 /** Return current url */
-	QUrl url ();
+	QUrl url () const { return current_url; };
 /** Return current url in a restorable way, i.e. for help pages, abstract the session specific part of the path */
 	QUrl restorableUrl ();
+/** Return the RKOutpuDirectory shown in this view (if any) */
+	RKOutputDirectory *outputDirectory() const { return dir; };
 
 	WindowMode mode () { return window_mode; };
 public slots:
-	void slotPrint ();
-	void slotSave ();
+	void slotPrint();
+	void slotExport();
+	void slotSave();
+	void slotSaveAs();
+	void slotRevert();
+	void slotActivate();
 	void slotForward ();
 	void slotBack ();
 	void selectionChanged ();
@@ -92,6 +90,7 @@ public slots:
 	void zoomIn ();
 	void zoomOut ();
 	void setTextEncoding (QTextCodec* encoding);
+	void updateState();
 private slots:
 	void scrollToBottom ();
 	void mimeTypeDetermined (KIO::Job*, const QString& type);
@@ -132,7 +131,8 @@ friend class RKHTMLWindowPart;
 	void fileDoesNotExistMessage ();
 
 	void saveBrowserState (VisitedLocation *state);
-
+/** the RKOutpuDirectory viewed in this window (if any) */
+	RKOutputDirectory *dir;
 friend class RKWebPage;
 	static RKWebPage *new_window;
 };
@@ -143,23 +143,26 @@ public:
 	explicit RKHTMLWindowPart (RKHTMLWindow *window);
 	~RKHTMLWindowPart () {};
 
-	void setOutputWindowSkin ();
-	void setHelpWindowSkin ();
-	void initActions ();
+	void setOutputDirectoryActionsEnabled(bool enable);
+	void setOutputWindowSkin();
+	void setHelpWindowSkin();
+	void initActions();
 private:
 friend class RKHTMLWindow;
 	RKHTMLWindow *window;
 
 	// general actions
-	QAction *run_selection;
+	QAction* run_selection;
 	QAction* print;
 	// actions in output window mode
 	QAction* outputFlush;
 	QAction* outputRefresh;
 	// actions in help window mode
-	QAction *back;
-	QAction *forward;
-	QAction* save_page;
+	QAction* back;
+	QAction* forward;
+	QAction* export_page;
+	QAction* revert;
+	QAction* activate;
 };
 
 /**
@@ -184,8 +187,8 @@ private:
 	QString renderHelpFragment (QDomElement &fragment);
 	QString resolveLabel (const QString &id) const;
 	QString prepareHelpLink (const QString &href, const QString &text);
-	QString componentPathToId (QString path);
-	RKComponentHandle *componentPathToHandle (QString path);
+	QString componentPathToId (const QString &path);
+	RKComponentHandle *componentPathToHandle (const QString &path);
 	QString startSection (const QString &name, const QString &title, const QString &shorttitle, QStringList *anchors, QStringList *anchor_names);
 
 	QIODevice *device;
@@ -196,7 +199,9 @@ private:
 
 #include <kdirwatch.h>
 
-/** Takes care of showing / refreshing output windows as needed. */
+/** Takes care of showing / refreshing output windows as needed.
+ *
+ *  For historical reasons, not all output windows refer to RKOutpuDirectories, which is why this separate class takes care of the mapping (for now). */
 class RKOutputWindowManager : public QObject {
 Q_OBJECT
 public:
@@ -205,10 +210,9 @@ public:
 	void registerWindow (RKHTMLWindow *window);
 /** R may produce output while no output window is active. This allows to set the file that should be monitored for such changes (called from within rk.set.html.output.file()). */
 	void setCurrentOutputPath (const QString &path);
-/** returns a list (possibly empty) of pointers to existing output windows (for the current output path, only). */
-	QList<RKHTMLWindow*> existingOutputWindows () const;
-/** Create (and show) a new output window, and @return the pointer */
-	RKHTMLWindow* newOutputWindow ();
+	QString currentOutputPath() const { return current_default_path; };
+/** returns a list (possibly empty) of pointers to existing output windows for the given path. */
+	QList<RKHTMLWindow*> existingOutputWindows (const QString &path) const;
 private:
 	RKOutputWindowManager ();
 	~RKOutputWindowManager ();
