@@ -1,33 +1,22 @@
-/***************************************************************************
-                          rwindowcatcher.cpp  -  description
-                             -------------------
-    begin                : Wed May 4 2005
-    copyright            : (C) 2005 - 2013 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rwindowcatcher.cpp - This file is part of RKWard (https://rkward.kde.org). Created: Wed May 4 2005
+SPDX-FileCopyrightText: 2005-2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rkwindowcatcher.h"
 
 #ifndef DISABLE_RKWINDOWCATCHER
 
-#include <qlayout.h>
-#include <qapplication.h>
-#include <QDesktopWidget>
+#include <QLayout>
+#include <QApplication>
 #include <QPushButton>
 #include <QDialogButtonBox>
 #include <QDialog>
 #include <QWindow>
 
-#include <kmessagebox.h>
+#include <KMessageBox>
 #include <KLocalizedString>
 #include <KWindowSystem>
 #include <KWindowInfo>
@@ -36,6 +25,7 @@
 #include "../dialogs/rkerrordialog.h"
 #include "rkworkplace.h"
 #include "../misc/rkstandardicons.h"
+#include "../misc/rkcommonfunctions.h"
 #include "../debug.h"
 
 RKWindowCatcher *RKWindowCatcher::_instance = 0;
@@ -202,7 +192,7 @@ void RKWindowCatcher::killDevice (int device_number) {
 	RKCaughtX11Window* window = RKCaughtX11Window::getWindow (device_number);
 	if (window) {
 		window->setKilledInR ();
-		window->close (true);
+		window->close (RKMDIWindow::AutoAskSaveModified);
 		QApplication::sync ();
 	}
 }
@@ -273,8 +263,6 @@ RKCaughtX11Window::RKCaughtX11Window (RKGraphicsDevice* rkward_device, int devic
 
 	commonInit (device_number);
 	rk_native_device = rkward_device;
-	xembed_container->setFixedSize (rk_native_device->viewPort ()->size ());
-	resize (xembed_container->size ());
 	rk_native_device->viewPort ()->setParent (xembed_container);
 	xembed_container->layout ()->addWidget (rk_native_device->viewPort ());
 	connect (rkward_device, &RKGraphicsDevice::captionChanged, this, &RKCaughtX11Window::setCaption);
@@ -282,6 +270,10 @@ RKCaughtX11Window::RKCaughtX11Window (RKGraphicsDevice* rkward_device, int devic
 	stop_interaction->setVisible (true);
 	stop_interaction->setEnabled (false);
 	setCaption (rkward_device->viewPort ()->windowTitle ());
+	rkward_device->viewPort()->setFixedSize(rkward_device->viewPort()->size()); // Prevent resizing *before* the window is shown. Will be re-enabled later
+	xembed_container->setFixedSize(rk_native_device->viewPort()->size());
+	xembed_container->show();
+	setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
 	QTimer::singleShot (0, this, SLOT (doEmbed()));
 }
@@ -289,7 +281,6 @@ RKCaughtX11Window::RKCaughtX11Window (RKGraphicsDevice* rkward_device, int devic
 void RKCaughtX11Window::commonInit (int device_number) {
 	RK_TRACE (MISC);
 
-	in_destructor = false;
 	capture = 0;
 	embedded = 0;
 	embedding_complete = false;
@@ -319,10 +310,13 @@ void RKCaughtX11Window::commonInit (int device_number) {
 	scroll_widget->setWidget (xembed_container);
 	xembed_container->hide (); // it seems to be important that the parent of a captured / embedded window is invisible prior to embedding.
 
-	dynamic_size = false;
 	dynamic_size_action->setChecked (false);
 }
 
+bool RKCaughtX11Window::dynamicSize() const {
+	return (xembed_container->parentWidget() == scroll_widget);
+}
+
 void RKCaughtX11Window::doEmbed () {
 	RK_TRACE (MISC);
 
@@ -337,6 +331,11 @@ void RKCaughtX11Window::doEmbed () {
 		xembed_container->layout ()->addWidget (capture);
 		xembed_container->show ();
 	}
+	if (rk_native_device) {
+		rk_native_device->viewPort()->setMinimumSize(5,5);
+		rk_native_device->viewPort()->setMaximumSize(32768,32768);
+		setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+	}
 
 	if (!isAttached ()) {
 		// make xembed_container resizable, again, now that it actually has a content
@@ -346,7 +345,7 @@ void RKCaughtX11Window::doEmbed () {
 
 	// try to be helpful when the window is too large to fit on screen
 	QRect dims = window ()->frameGeometry ();
-	QRect avail = QApplication::desktop ()->availableGeometry (window ());
+	QRect avail = RKCommonFunctions::availableGeometry(window());
 	if ((dims.width () > avail.width ()) || (dims.height () > avail.height ())) {
 		KMessageBox::information (this, i18n ("The current window appears too large to fit on the screen. If this happens regularly, you may want to adjust the default graphics window size in Settings->Configure RKWard->Onscreen Graphics."), i18n ("Large window"), "dont_ask_again_large_x11_window");
 	}
@@ -357,12 +356,33 @@ RKCaughtX11Window::~RKCaughtX11Window () {
 	RK_ASSERT (device_windows.contains (device_number));
 	device_windows.remove (device_number);
 
-	in_destructor = true;
-	close (false);
+	commonClose(true);
+
 	if (embedded) RKWindowCatcher::instance ()->unregisterWatcher (embedded->winId ());
 	error_dialog->autoDeleteWhenDone ();
 }
 
+void RKCaughtX11Window::commonClose(bool in_destructor) {
+	RK_TRACE(MISC);
+
+	if (rk_native_device) rk_native_device->stopInteraction();
+
+	QString status = i18n("Closing device (saving history)");
+	if (!(close_attempted || killed_in_r)) {
+		RCommand* c = new RCommand("dev.off (" + QString::number(device_number) + ')', RCommand::App, i18n("Shutting down device number %1", device_number));
+		if (!in_destructor) setStatusMessage(status, c);
+		RKGlobals::rInterface()->issueCommand(c);
+		close_attempted = true;
+	} else {
+		if (in_destructor) return;
+		if (KMessageBox::questionYesNo(this, i18n("<p>The graphics device is being closed, saving the last plot to the plot history. This may take a while, if the R backend is still busy. You can close the graphics device immediately, in case it is stuck. However, the last plot may be missing from the plot history, if you do this.</p>")
+#if !defined Q_OS_WIN
+		+ i18n("<p>Note: On X11, the embedded window may be expurged, and you will have to close it manually in this case.</p>")
+#endif
+		, status, KGuiItem(i18n("Close immediately")), KGuiItem(i18n("Keep waiting"))) == KMessageBox::Yes) forceClose();
+	}
+}
+
 void RKCaughtX11Window::setWindowStyleHint (const QString& hint) {
 	RK_TRACE (MISC);
 
@@ -374,40 +394,25 @@ void RKCaughtX11Window::setWindowStyleHint (const QString& hint) {
 	RKMDIWindow::setWindowStyleHint (hint);
 }
 
-void RKCaughtX11Window::forceClose () {
+void RKCaughtX11Window::forceClose() {
 	killed_in_r = true;
 	if (embedded) {
 		// HACK: Somehow (R 3.0.0alpha), the X11() window is surprisingly die-hard, if it is not closed "the regular way".
 		// So we expurge it, and leave the rest to the user.
-		embedded->setParent (0);
-		qApp->processEvents ();
+		embedded->setParent(0);
+		qApp->processEvents();
 	}
-	RKMDIWindow::close (true);
+	RKMDIWindow::close(NoAskSaveModified);
 }
 
-bool RKCaughtX11Window::close (bool also_delete) {
-	RK_TRACE (MISC);
+bool RKCaughtX11Window::close(CloseWindowMode ask_save) {
+	RK_TRACE(MISC);
 
-	if (killed_in_r || RKGlobals::rInterface ()->backendIsDead ()) {
-		return RKMDIWindow::close (also_delete);
-	}
-
-	if (rk_native_device) rk_native_device->stopInteraction ();
-
-	QString status = i18n ("Closing device (saving history)");
-	if (!close_attempted) {
-		RCommand* c = new RCommand ("dev.off (" + QString::number (device_number) + ')', RCommand::App, i18n ("Shutting down device number %1", device_number));
-		if (!in_destructor) setStatusMessage (status, c);
-		RKGlobals::rInterface ()->issueCommand (c);
-		close_attempted = true;
-	} else {
-		if (KMessageBox::questionYesNo (this, i18n ("<p>The graphics device is being closed, saving the last plot to the plot history. This may take a while, if the R backend is still busy. You can close the graphics device immediately, in case it is stuck. However, the last plot may be missing from the plot history, if you do this.</p>")
-#if !defined Q_OS_WIN
-		+ i18n ("<p>Note: On X11, the embedded window may be expurged, and you will have to close it manually in this case.</p>")
-#endif
-		, status, KGuiItem (i18n ("Close immediately")), KGuiItem (i18n ("Keep waiting"))) == KMessageBox::Yes) forceClose ();
+	if (killed_in_r || RKGlobals::rInterface()->backendIsDead()) {
+		return RKMDIWindow::close(ask_save);
 	}
 
+	commonClose(false);
 	return false;
 }
 
@@ -453,18 +458,16 @@ void RKCaughtX11Window::fixedSizeToggled () {
 	RK_TRACE (MISC);
 
 	if (embedded && !capture) return;  // while in the middle of embedding, don't mess with any of this, it seems to cause trouble
-	if (dynamic_size == dynamic_size_action->isChecked ()) return;
-	dynamic_size = dynamic_size_action->isChecked ();
+	if (dynamicSize() == dynamic_size_action->isChecked ()) return;
 
 	if (dynamic_size_action->isChecked ()) {
-		scroll_widget->takeWidget ();
+		if (scroll_widget->widget()) scroll_widget->takeWidget();
 		scroll_widget->hide ();
 		layout ()->addWidget (xembed_container);
 		xembed_container->show ();
 		xembed_container->setMinimumSize (5, 5);
 		xembed_container->setMaximumSize (32767, 32767);
 	} else {
-		xembed_container->setFixedSize (xembed_container->size ());
 		layout ()->removeWidget (xembed_container);
 		scroll_widget->setWidget (xembed_container);
 		scroll_widget->show ();
